@@ -5,10 +5,10 @@ track dependencies between them. It initiates the run, compiles the results, and
 handles the final output. It maintains the help list for all options available
 in the run.
 
-  The setup() method preforms generic Script setup and then is called recursively
+  The setup() method performs generic Script setup and then is called recursively
 on all the child modules. The cleanup() method performs the final output and
 logging actions
-    - Subtitute files
+    - Substitute files
     - Output configure header
     - Log filesystem actions
 
@@ -51,16 +51,8 @@ import os
 import re
 import sys
 import platform
-# workaround for python2.2 which does not have pathsep
-if not hasattr(os.path,'pathsep'): os.path.pathsep=':'
-
 import pickle
-
-try:
-  from hashlib import md5 as new_md5
-except ImportError:
-  from md5 import new as new_md5 # novermin
-
+from hashlib import md5 as new_md5
 
 class Framework(config.base.Configure, script.LanguageProcessor):
   '''This needs to manage configure information in itself just as Builder manages it for configurations'''
@@ -226,14 +218,14 @@ class Framework(config.base.Configure, script.LanguageProcessor):
       self.logWrite('    Files in path provided by default path\n')
       logPrintFilesInPath(os.environ['PATH'].split(os.path.pathsep))
     dirs = self.argDB['with-executables-search-path']
-    if not isinstance(dirs, list): dirs = [dirs]
+    if not isinstance(dirs, list): dirs = dirs.split(os.path.pathsep)
     if dirs:
       self.logWrite('    Files in path provided by --with-executables-search-path\n')
       logPrintFilesInPath(dirs)
 
   def dumpConfFiles(self):
     '''Performs:
-       - Subtitute files
+       - Substitute files
        - Output configure header
        - Log actions'''
     self.substitute()
@@ -438,6 +430,7 @@ class Framework(config.base.Configure, script.LanguageProcessor):
     # Intel
     lines = [s for s in lines if s.find("icc: command line remark #10148: option '-i-dynamic' not supported") < 0]
     lines = [s for s in lines if s.find("[: unexpected operator") < 0]  # Deals with error in mpiicc and mpiicpc wrappers from some versions of Intel MPI.
+    lines = [s for s in lines if s.find(': remark #10441:') < 0]
     # IBM:
     lines = [s for s in lines if not s.startswith('cc_r:')]
     # PGI: Ignore warning about temporary license
@@ -453,12 +446,16 @@ class Framework(config.base.Configure, script.LanguageProcessor):
     lines = [s for s in lines if s.find('The -gpu option has no effect unless a language-specific option to enable GPU code generation is used') < 0]
     # pgi dumps filename on stderr - but returns 0 errorcode'
     lines = [s for s in lines if lines != 'conftest.c:']
+
+    lines = [s for s in lines if len(s)]
     if lines: output = '\n'.join(lines)
     else: output = ''
     log.write("Preprocess output after filtering:\n"+output+":\n")
     return output
 
-  def filterCompileOutput(self, output):
+  def filterCompileOutput(self, output,flag = ''):
+    if flag and output.find("ignoring unknown option '"+flag+"'"): return output
+    if flag and output.find("invalid value"): return output
     if output.find('warning:  attribute "deprecated" is unknown, ignored') >= 0: return output
     if output.find('PGC-W-0129-Floating point overflow') >= 0: return output
     if output.find('warning #264: floating-point value does not fit in required floating-point type') >= 0: return output
@@ -491,6 +488,7 @@ class Framework(config.base.Configure, script.LanguageProcessor):
       lines = [s for s in lines if s.find('warning: unused variable') < 0]
       # Intel
       lines = [s for s in lines if s.find("icc: command line remark #10148: option '-i-dynamic' not supported") < 0]
+      lines = [s for s in lines if s.find(': remark #10441:') < 0]
       # PGI: Ignore warning about temporary license
       lines = [s for s in lines if s.find('license.dat') < 0]
       # Cray XT3
@@ -505,6 +503,8 @@ class Framework(config.base.Configure, script.LanguageProcessor):
       lines = [s for s in lines if s.find('The -gpu option has no effect unless a language-specific option to enable GPU code generation is used') < 0]
       # pgi dumps filename on stderr - but returns 0 errorcode'
       lines = [s for s in lines if lines != 'conftest.c:']
+
+      lines = [s for s in lines if len(s)]
       if lines: output = '\n'.join(lines)
       else: output = ''
       self.log.write("Compiler output after filtering:\n"+output+":\n")
@@ -523,6 +523,7 @@ class Framework(config.base.Configure, script.LanguageProcessor):
         lines = [s for s in lines if not self.warningRE.search(s)]
       #Intel
       lines = [s for s in lines if s.find(": command line warning #10121: overriding") < 0]
+      lines = [s for s in lines if s.find(': remark #10441:') < 0]
       # PGI: Ignore warning about temporary license
       lines = [s for s in lines if s.find('license.dat') < 0]
       # Cray XT3
@@ -557,8 +558,20 @@ class Framework(config.base.Configure, script.LanguageProcessor):
       lines = [s for s in lines if s.find(' was built for newer macOS version') < 0]
       lines = [s for s in lines if s.find(' was built for newer OSX version') < 0]
       lines = [s for s in lines if s.find(' stack subq instruction is too different from dwarf stack size') < 0]
+      lines = [s for s in lines if s.find('could not create compact unwind') < 0]
+      lines = [s for s in lines if s.find('ld: warning: -undefined dynamic_lookup may not work with chained fixups') < 0]
       # Nvidia linker
       lines = [s for s in lines if s.find('nvhpc.ld contains output sections') < 0]
+      # Intel dpcpp linker
+      # Ex. clang-offload-bundler: error: '/home/jczhang/mpich/lib': Is a directory
+      lines = [s for s in lines if s.find('clang-offload-bundler: error:') < 0]
+      lines = [s for s in lines if s.find('Compilation from IR - skipping loading of FCL') < 0]
+      lines = [s for s in lines if s.find('Build succeeded') < 0]
+
+      lines = [s for s in lines if len(s)]
+      # a line with a single : can be created on macOS when the linker jumbles the output from warning messages with was "built for newer" warnings
+      lines = [s for s in lines if s != ':']
+
       if lines: output = '\n'.join(lines)
       else: output = ''
       self.log.write("Linker output after filtering:\n"+output+":\n")
@@ -792,7 +805,7 @@ class Framework(config.base.Configure, script.LanguageProcessor):
     if not hasattr(child, 'version_tuple') or not isinstance(child.version_tuple, tuple): return
     if not child.version_tuple: return
     vt = child.version_tuple
-    prefix = 'PETSC_PKG_'+child.name.upper()+('_')
+    prefix = 'PETSC_PKG_'+child.name.upper().replace('-','_')+('_') # Ex. convert KOKKOS-KERNELS to KOKKOS_KERNELS
     ss = ('VERSION_MAJOR','VERSION_MINOR','VERSION_SUBMINOR')
     # output versioning tuple
     for t in range(min(len(vt),3)):
@@ -856,8 +869,9 @@ class Framework(config.base.Configure, script.LanguageProcessor):
     self.outputMakeMacros(f, self)
     for child in self.childGraph.vertices:
       self.outputMakeMacros(f, child)
-    # The testoptions are provided in packages/
+    # This options are used in all runs of the test harness
     testoptions = ''
+    # Additional testoptions are provided in packages/
     for child in self.childGraph.vertices:
         if hasattr(child,'found') and child.found and hasattr(child,'testoptions') and child.testoptions:
           testoptions += ' '+child.testoptions
@@ -1029,6 +1043,7 @@ class Framework(config.base.Configure, script.LanguageProcessor):
     return
 
   def configureExternalPackagesDir(self):
+    '''Set alternative directory external packages are built in'''
     if 'with-packages-build-dir' in self.argDB:
       self.externalPackagesDir = self.argDB['with-packages-build-dir']
     else:
@@ -1230,7 +1245,7 @@ class Framework(config.base.Configure, script.LanguageProcessor):
             out += tb.getvalue()
             tb.close()
           except: pass
-        # Udpate queue
+        # Update queue
         #self.logPrint('PUSH  %s to DONE ' % child.__class__.__module__)
         done.put((ret, out, emsg, child))
         q.task_done() # novermin
@@ -1270,69 +1285,78 @@ class Framework(config.base.Configure, script.LanguageProcessor):
   def serialEvaluation(self, depGraph):
     import graph
 
-    ndepGraph = graph.DirectedGraph.topologicalSort(depGraph)
-    foundSetCompilers = False
-    foundCompilers    = False
-    for child in ndepGraph:
-      if hasattr(child,'setCompilers') and not foundSetCompilers:
-        setCompilers = child.setCompilers
-        foundSetCompilers = True
-      elif hasattr(child,'compilers') and not foundCompilers:
-        compilers      = child.compilers
-        foundCompilers = True
-      if foundCompilers and foundSetCompilers: break
+    def findModule(dependencyGraph,moduleType):
+      moduleList = [c for c in dependencyGraph if isinstance(c,moduleType)]
+      if len(moduleList) != 1:
+        if len(moduleList) < 1:
+          errorMessage = 'Did not find module {} in graph'.format(moduleType)
+        else:
+          errorMessage = 'Found multiple instances of module {} in graph'.format(moduleType)
+        raise RuntimeError(errorMessage)
+      return moduleList[0]
 
-    minCxx,maxCxx = compilers.cxxDialectRange
-    self.logPrint('serialEvaluation: initial cxxDialectRanges {rng}'.format(rng=compilers.cxxDialectRange))
+    def checkChildCxxDialectBounds(child,minCxx,maxCxx):
+      if child.minCxxVersion > minCxx:
+        minCxx = child.minCxxVersion
+        self.logPrint('serialEvaluation: child {child} raised minimum cxx dialect version to {minver}'.format(child=child.name,minver=minCxx))
+        try:
+          minCxxVersionBlameList[minCxx].add([child.name])
+        except KeyError:
+          minCxxVersionBlameList[minCxx] = set([child.name])
+      if child.maxCxxVersion < maxCxx:
+        maxCxx = child.maxCxxVersion
+        self.logPrint('serialEvaluation: child {child} decreased maximum cxx dialect version to {maxver}'.format(child=child.name,maxver=maxCxx))
+        try:
+          maxCxxVersionBlameList[maxCxx].add([child.name])
+        except KeyError:
+          maxCxxVersionBlameList[maxCxx] = set([child.name])
+      return minCxx,maxCxx
+
+    ndepGraph     = list(graph.DirectedGraph.topologicalSort(depGraph))
+    setCompilers  = findModule(ndepGraph,config.setCompilers.Configure)
+    minCxx,maxCxx = setCompilers.cxxDialectRange['Cxx']
+    self.logPrint('serialEvaluation: initial cxxDialectRanges {rng}'.format(rng=setCompilers.cxxDialectRange['Cxx']))
     minCxxVersionBlameList = {}
     maxCxxVersionBlameList = {}
-    ndepGraph = graph.DirectedGraph.topologicalSort(depGraph)
     for child in ndepGraph:
       if (self.argDB['with-batch'] and
           hasattr(child,'package') and
           'download-'+child.package in self.framework.clArgDB and
           self.argDB['download-'+child.package] and not
-          (hasattr(setCompilers,'cross_cc') or child.installwithbatch)): raise RuntimeError('--download-'+child.package+' cannot be used on this batch systems\n')
+          (hasattr(setCompilers,'cross_cc') or child.installwithbatch)):
+        errorMessage = '--download-'+child.package+' cannot be used on this batch systems'
+        raise RuntimeError(errorMessage)
 
       # note, only classes derived from package.py have this attribute
       if hasattr(child,'deps'):
         found = 0
         if child.required or child.lookforbydefault: found = 1
-        if 'download-'+child.package in self.framework.clArgDB and self.argDB['download-'+child.package]: found = 1
-        if 'with-'+child.package in self.framework.clArgDB and self.argDB['with-'+child.package]: found = 1
-        if 'with-'+child.package+'-lib' in self.framework.clArgDB and self.argDB['with-'+child.package+'-lib']: found = 1
-        if 'with-'+child.package+'-dir' in self.framework.clArgDB and self.argDB['with-'+child.package+'-dir']: found = 1
+        elif 'download-'+child.package in self.framework.clArgDB and self.argDB['download-'+child.package]: found = 1
+        elif 'with-'+child.package in self.framework.clArgDB and self.argDB['with-'+child.package]: found = 1
+        elif 'with-'+child.package+'-lib' in self.framework.clArgDB and self.argDB['with-'+child.package+'-lib']: found = 1
+        elif 'with-'+child.package+'-dir' in self.framework.clArgDB and self.argDB['with-'+child.package+'-dir']: found = 1
         if not found: continue
         msg = ''
+        minCxx,maxCxx = checkChildCxxDialectBounds(child,minCxx,maxCxx)
         for dep in child.deps:
-          found = 0
-          if dep.required or dep.lookforbydefault: found = 1
-          if 'download-'+dep.package in self.framework.clArgDB and self.argDB['download-'+dep.package]: found = 1
-          if 'with-'+dep.package in self.framework.clArgDB and self.argDB['with-'+dep.package]: found = 1
-          if 'with-'+dep.package+'-lib' in self.framework.clArgDB and self.argDB['with-'+dep.package+'-lib']: found = 1
-          if 'with-'+dep.package+'-dir' in self.framework.clArgDB and self.argDB['with-'+dep.package+'-dir']: found = 1
-          if found:
-            if child.minCxxVersion > minCxx:
-              minCxx = child.minCxxVersion
-              self.logPrint('serialEvaluation: child {child} raised minimum cxx dialect version to {minver}'.format(child=child.name,minver=minCxx))
-              try:
-                minCxxVersionBlameList[minCxx].add([child.name])
-              except KeyError:
-                minCxxVersionBlameList[minCxx] = set([child.name])
-            if child.maxCxxVersion < maxCxx:
-              maxCxx = child.maxCxxVersion
-              self.logPrint('serialEvaluation: child {child} decreased maximum cxx dialect version to {maxver}'.format(child=child.name,maxver=maxCxx))
-              try:
-                maxCxxVersionBlameList[maxCxx].add([child.name])
-              except KeyError:
-                maxCxxVersionBlameList[maxCxx] = set([child.name])
+          if dep.required or dep.lookforbydefault:
+            continue
+          elif 'download-'+dep.package in self.framework.clArgDB and self.argDB['download-'+dep.package]:
+            continue
+          elif 'with-'+dep.package in self.framework.clArgDB and self.argDB['with-'+dep.package]:
+            continue
+          elif 'with-'+dep.package+'-lib' in self.framework.clArgDB and self.argDB['with-'+dep.package+'-lib']:
+            continue
+          elif 'with-'+dep.package+'-dir' in self.framework.clArgDB and self.argDB['with-'+dep.package+'-dir']:
+            continue
+          elif dep.download:
+            emsg = '--download-'+dep.package+' or '
           else:
-            if dep.download: emsg = '--download-'+dep.package+' or '
-            else: emsg = ''
-            msg += 'Package '+child.package+' requested but dependency '+dep.package+' not requested. \n  Perhaps you want '+emsg+'--with-'+dep.package+'-dir=directory or --with-'+dep.package+'-lib=libraries and --with-'+dep.package+'-include=directory\n'
+            emsg = ''
+          msg += 'Package '+child.package+' requested but dependency '+dep.package+' not requested. \n  Perhaps you want '+emsg+'--with-'+dep.package+'-dir=directory or --with-'+dep.package+'-lib=libraries and --with-'+dep.package+'-include=directory\n'
         if msg: raise RuntimeError(msg)
-        if child.cxx and ('with-cxx' in self.framework.clArgDB) and (self.argDB['with-cxx'] == '0'): raise RuntimeError('Package '+child.package+' requested requires C++ but compiler turned off.')
-        if child.fc and ('with-fc' in self.framework.clArgDB) and (self.argDB['with-fc'] == '0'): raise RuntimeError('Package '+child.package+' requested requires Fortran but compiler turned off.')
+        if 'Cxx' in child.buildLanguages and ('with-cxx' in self.framework.clArgDB) and (self.argDB['with-cxx'] == '0'): raise RuntimeError('Package '+child.package+' requested requires C++ but compiler turned off.')
+        if 'FC'  in child.buildLanguages and ('with-fc' in self.framework.clArgDB) and (self.argDB['with-fc'] == '0'): raise RuntimeError('Package '+child.package+' requested requires Fortran but compiler turned off.')
 
     if maxCxx < minCxx:
       # low water mark
@@ -1340,9 +1364,9 @@ class Framework(config.base.Configure, script.LanguageProcessor):
       # high water mark
       hiPack = ', '.join(maxCxxVersionBlameList[maxCxx])
       raise RuntimeError('Requested package(s) have incompatible C++ requirements. Package(s) {loPacks} require at least {mincxx} but package(s) {hiPack} require at most {maxcxx}'.format(loPack=loPack,mincxx=minCxx,hiPack=hiPack,maxcxx=maxCxx))
-    compilers.cxxDialectPackageRanges = (minCxxVersionBlameList,maxCxxVersionBlameList)
+    setCompilers.cxxDialectPackageRanges = (minCxxVersionBlameList,maxCxxVersionBlameList)
     self.logPrint('serialEvaluation: new cxxDialectRanges {rng}'.format(rng=(minCxx,maxCxx)))
-    depGraph = graph.DirectedGraph.topologicalSort(depGraph)
+    depGraph  = graph.DirectedGraph.topologicalSort(depGraph)
     totaltime = 0
     starttime = time.time()
     for child in depGraph:
@@ -1354,7 +1378,7 @@ class Framework(config.base.Configure, script.LanguageProcessor):
       child._configured = 1
       ctime = time.time()-start
       totaltime = totaltime + ctime
-      self.logPrint('child %s %f' % (child.__class__.__module__,ctime))
+      self.logPrint('child %s took %f seconds' % (child.__class__.__module__,ctime))
     self.logPrint('child sum %f' % (totaltime))
     self.logPrint('child total %f' % (time.time()-starttime))
     # use grep child configure.log | sort -k3 -g
