@@ -10,9 +10,7 @@ class Configure(config.package.CMakePackage):
     self.downloaddirnames = ['trilinos']
     self.includes         = ['Trilinos_version.h']
     self.functions        = ['Zoltan_Create']   # one of the very few C routines in Trilinos
-    self.cxx              = 1
-    self.requirescxx11    = 1
-    self.downloadonWindows= 0
+    self.buildLanguages   = ['Cxx']
     self.hastests         = 1
     self.requiresrpath    = 1
     self.precisions       = ['double']
@@ -76,7 +74,7 @@ class Configure(config.package.CMakePackage):
 
   # older versions of Trilinos require passing rpath with the various library paths
   # this caused problems on Apple with cmake generating command lines that are too long
-  # Trilinos was fixed to handled the rpath internally using cmake 
+  # Trilinos was fixed to handled the rpath internally using cmake
   def toStringNoDupes(self,string):
     string    = self.libraries.toStringNoDupes(string)
     if self.requiresrpath: return string
@@ -288,7 +286,7 @@ class Configure(config.package.CMakePackage):
       os.unlink('simplemake')
     except RuntimeError as e:
       raise RuntimeError('Unable to generate list of Trilinos Libraries')
-    # generateLibList() wants this ridiculus format
+    # generateLibList() wants this ridiculous format
     l = output1.split(' ')
     ll = [os.path.join(dir,'lib'+l[0][2:]+'.a')]
     for i in l[1:]:
