@@ -1,3 +1,6 @@
+# Portions of this code are under:
+# Copyright (c) 2022 Advanced Micro Devices, Inc. All rights reserved.
+
 import config.package
 import os
 
@@ -12,13 +15,12 @@ class Configure(config.package.Package):
     self.functionsCxx     = [1,'', 'rocblas_create']
     self.includes         = ['hip/hip_runtime.h']
     # PETSc does not use hipsparse or hipblas, but dependencies can (e.g., magma)
-    self.liblist          = [['libhipsparse.a','libhipblas.a','librocsparse.a','librocsolver.a','librocblas.a','librocrand.a','libamdhip64.a'],
-                             ['hipsparse.lib','hipblas.lib','rocsparse.lib','rocsolver.lib','rocblas.lib','rocrand.lib','amdhip64.lib'],]
+    self.liblist          = [['libhipsparse.a','libhipblas.a','libhipsolver.a','librocsparse.a','librocsolver.a','librocblas.a','librocrand.a','libamdhip64.a'],
+                             ['hipsparse.lib','hipblas.lib','hipsolver.lib','rocsparse.lib','rocsolver.lib','rocblas.lib','rocrand.lib','amdhip64.lib'],]
     self.precisions       = ['single','double']
-    self.cxx              = 1
-    self.complex          = 1
-    self.hastests         = 0
-    self.hastestsdatafiles= 0
+    self.buildLanguages   = ['HIP']
+    self.devicePackage    = 1
+    self.fullPathHIPC     = ''
     return
 
   def setupHelp(self, help):
@@ -39,18 +41,6 @@ class Configure(config.package.Package):
       output += '  HIP arch: '+ self.hipArch +'\n'
     return output
 
-  def getSearchDirectories(self):
-    import os
-    self.pushLanguage('HIP')
-    petscHip = self.getCompiler()
-    self.popLanguage()
-    self.getExecutable(petscHip,getFullPath=1,resultName='systemHipc')
-    if hasattr(self,'systemHipc'):
-      hipcDir = os.path.dirname(self.systemHipc)
-      hipDir = os.path.split(hipcDir)[0]
-      yield hipDir
-    return
-
   def checkSizeofVoidP(self):
     '''Checks if the HIPC compiler agrees with the C compiler on what size of void * should be'''
     self.log.write('Checking if sizeof(void*) in HIP is the same as with regular compiler\n')
@@ -78,7 +68,24 @@ class Configure(config.package.Package):
         raise RuntimeError('HIP compiler error: memory alignment doesn\'t match C compiler (try adding -malign-double to compiler options)')
     return
 
+  def setFullPathHIPC(self):
+    self.pushLanguage('HIP')
+    HIPC = self.getCompiler()
+    self.popLanguage()
+    self.getExecutable(HIPC,getFullPath=1,resultName='fullPathHIPC')
+    if not hasattr(self,'fullPathHIPC'):
+      raise RuntimeError('Unable to locate the HIPC compiler')
+
+  def getSearchDirectories(self):
+    # Package.getSearchDirectories() return '' by default, so that HIPC's default include path could
+    # be checked. But here we lower priority of '', so that once we validated a header path, it will
+    # be added to HIP_INCLUDE.  Other compilers, ex. CC or CXX, might need this path for compilation.
+    yield os.path.dirname(os.path.dirname(self.fullPathHIPC)) # yield /opt/rocm from /opt/rocm/bin/hipcc
+    yield ''
+
   def configureLibrary(self):
+    self.setFullPathHIPC()
+    config.package.Package.configureLibrary(self)
     self.getExecutable('hipconfig',getFullPath=1,resultName='hip_config')
     if hasattr(self,'hip_config'):
       try:
@@ -142,7 +149,17 @@ class Configure(config.package.Package):
       else:
         raise RuntimeError('You must set --with-hip-arch=gfx900, gfx906, gfx908, gfx90a etc or make ROCM utility "rocminfo" available on your PATH')
 
-    config.package.Package.configureLibrary(self)
+      # Record rocBlas and rocSparse directories as they are needed by Kokkos-Kernels HIP TPL, so that we can handle
+      # a weird (but valid) case --with-hipcc=/opt/rocm-4.5.2/hip/bin/hipcc --with-hip-dir=/opt/rocm-4.5.2 (which
+      # should be better written as --with-hipcc=/opt/rocm-4.5.2/bin/hipcc --with-hip-dir=/opt/rocm-4.5.2 or simply
+      # --with-hip-dir=/opt/rocm-4.5.2)
+      if self.directory:
+        self.rocBlasDir   = self.directory
+        self.rocSparseDir = self.directory
+      else: # directory is '', indicating we are using the compiler's default, so the last resort is to guess the dir from hipcc
+        hipDir            = os.path.dirname(os.path.dirname(self.fullPathHIPC)) # Ex. peel /opt/rocm-4.5.2/bin/hipcc twice
+        self.rocBlasDir   = hipDir
+        self.rocSparseDir = hipDir
     #self.checkHIPDoubleAlign()
     self.configureTypes()
     self.libraries.popLanguage()
