@@ -18,7 +18,7 @@ configure_options = [
   '--with-openmp=1',
   '--download-hwloc=1',
   #'--download-hypre=1', disabled as hypre produces wrong results when openmp is enabled
-  '--download-cmake=1',
+  #'--download-cmake=1',
   '--download-metis=1',
   '--download-parmetis=1',
   '--download-ptscotch=1',
@@ -34,6 +34,7 @@ configure_options = [
   '--download-parms=1',
   '--download-kokkos=1',
   '--download-kokkos-kernels=1',
+  '--with-kokkos-init-warnings=0', # we want to avoid "Kokkos::OpenMP::initialize WARNING: You are likely oversubscribing your CPU cores" in test output
   '--download-chaco=1'
   ]
 
