@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 from __future__ import print_function
 import os, re, shutil, sys
 
@@ -154,7 +154,7 @@ class Installer(script.Script):
     alllines=oldFile.read()
     oldFile.close()
     newlines=alllines.split('\n')[0]+'\n'  # Firstline
-    # Hardcode PETSC_DIR and PETSC_ARCH to avoid users doing the worng thing
+    # Hardcode PETSC_DIR and PETSC_ARCH to avoid users doing the wrong thing
     newlines+='PETSC_DIR='+self.installDir+'\n'
     newlines+='PETSC_ARCH=\n'
     for line in alllines.split('\n')[1:]:
@@ -181,7 +181,7 @@ class Installer(script.Script):
     newConfigDir=os.path.join(dst,'config')  # Am not renaming at present
     if not os.path.isdir(newConfigDir): os.mkdir(newConfigDir)
     testConfFiles="gmakegentest.py gmakegen.py testparse.py example_template.py".split()
-    testConfFiles+="petsc_harness.sh report_tests.py".split()
+    testConfFiles+="petsc_harness.sh report_tests.py query_tests.py".split()
     for tf in testConfFiles:
       self.copies.extend(self.copyfile(os.path.join('config',tf),newConfigDir))
     return
@@ -274,6 +274,8 @@ class Installer(script.Script):
       line = line.replace('${PETSC_DIR}/${PETSC_ARCH}', self.installDir)
       line = line.replace('PETSC_ARCH=${PETSC_ARCH}', '')
       line = line.replace('${PETSC_DIR}', self.installDir)
+      # replace PETSC_DIR/lib/petsc/bin with prefix/lib/petsc/bin
+      line = line.replace(self.rootBinDir,self.destBinDir)
       lines.append(line)
     oldFile.close()
     newFile = open(src, 'w')
@@ -333,7 +335,7 @@ for file in files:
     if not self.mpi.usingMPIUni:
       exclude.append('petsc-mpiexec.uni')
     self.setCompilers.pushLanguage('C')
-    if not self.setCompilers.isWindows(self.setCompilers.getCompiler(),self.log):
+    if self.setCompilers.getCompiler().find('win32fe') < 0:
       exclude.append('win32fe')
     self.setCompilers.popLanguage()
     self.copies.extend(self.copytree(self.rootBinDir, self.destBinDir, exclude = exclude ))
@@ -363,7 +365,7 @@ for file in files:
       os.symlink(linkto, dst)
       return
     shutil.copy2(src, dst)
-    if os.path.splitext(dst)[1] == '.'+self.arLibSuffix:
+    if self.setCompilers.getCompiler().find('win32fe') < 0 and os.path.splitext(dst)[1] == '.'+self.arLibSuffix:
       self.executeShellCommand(self.ranlib+' '+dst)
     if os.path.splitext(dst)[1] == '.dylib' and os.path.isfile('/usr/bin/install_name_tool'):
       [output,err,flg] = self.executeShellCommand("otool -D "+src)
