@@ -15,7 +15,7 @@
 #define DMDALocalInfo PetscInt
 !
 !   DMDA_LOCAL_INFO_SIZE is one large than the size incase the DA is larger than an integer (on 64 bit systems).
-!   non-int fields are not accessiable from fortran.
+!   non-int fields are not accessible from Fortran.
 !
 #define DMDA_LOCAL_INFO_SIZE 25
 #define DMDA_LOCAL_INFO_DIM 1
