@@ -1,4 +1,4 @@
-#if !defined(_DT_H)
+#ifndef _DT_H
 #define _DT_H
 
 #include <petscdt.h>
@@ -13,4 +13,10 @@ struct _p_PetscQuadrature {
   const PetscReal *weights;   /* The quadrature weights */
 };
 
+#if (!defined(PETSC_MISSING_LAPACK_STEQR) || !defined(PETSC_MISSING_LAPACK_STEGR))
+  #define PETSCDTGAUSSIANQUADRATURE_EIG 1
+#endif
+
+PETSC_EXTERN PetscBool PetscDTGaussQuadratureNewton_Internal;
+
 #endif
