@@ -11,8 +11,8 @@
 /*     pages 626-637, 1983.                                                  */
 /*****************************************************************************/
 
-#if !defined(__CG_STCG)
-#define __CG_STCG
+#ifndef PETSC_CG_STCGIMPL_H
+#define PETSC_CG_STCGIMPL_H
 
 #include <petsc/private/kspimpl.h>
 
@@ -23,5 +23,4 @@ typedef struct {
   PetscInt  dtype;
 } KSPCG_STCG;
 
-#endif
-
+#endif // PETSC_CG_STCGIMPL_H
