@@ -2,14 +2,6 @@
 static char help[] = "Solves a linear system in parallel with KSP and DM.\n\
 Compare this to ex2 which solves the same problem without a DM.\n\n";
 
-/*T
-   Concepts: KSP^basic parallel example;
-   Concepts: KSP^Laplacian, 2d
-   Concepts: DM^using distributed arrays;
-   Concepts: Laplacian, 2d
-   Processors: n
-T*/
-
 /*
   Include "petscdmda.h" so that we can use distributed arrays (DMDAs).
   Include "petscksp.h" so that we can use KSP solvers.  Note that this file
@@ -23,31 +15,31 @@ T*/
 #include <petscdmda.h>
 #include <petscksp.h>
 
-int main(int argc,char **argv)
+int main(int argc, char **argv)
 {
-  DM             da;            /* distributed array */
-  Vec            x,b,u;         /* approx solution, RHS, exact solution */
-  Mat            A;             /* linear system matrix */
-  KSP            ksp;           /* linear solver context */
-  PetscRandom    rctx;          /* random number generator context */
-  PetscReal      norm;          /* norm of solution error */
-  PetscInt       i,j,its;
-  PetscErrorCode ierr;
-  PetscBool      flg = PETSC_FALSE;
+  DM          da;      /* distributed array */
+  Vec         x, b, u; /* approx solution, RHS, exact solution */
+  Mat         A;       /* linear system matrix */
+  KSP         ksp;     /* linear solver context */
+  PetscRandom rctx;    /* random number generator context */
+  PetscReal   norm;    /* norm of solution error */
+  PetscInt    i, j, its;
+  PetscBool   flg = PETSC_FALSE;
 #if defined(PETSC_USE_LOG)
-  PetscLogStage  stage;
+  PetscLogStage stage;
 #endif
-  DMDALocalInfo  info;
+  DMDALocalInfo info;
 
-  ierr = PetscInitialize(&argc,&argv,(char*)0,help);if (ierr) return ierr;
+  PetscFunctionBeginUser;
+  PetscCall(PetscInitialize(&argc, &argv, (char *)0, help));
   /*
      Create distributed array to handle parallel distribution.
      The problem size will default to 8 by 7, but this can be
      changed using -da_grid_x M -da_grid_y N
   */
-  ierr = DMDACreate2d(PETSC_COMM_WORLD, DM_BOUNDARY_NONE, DM_BOUNDARY_NONE,DMDA_STENCIL_STAR,8,7,PETSC_DECIDE,PETSC_DECIDE,1,1,NULL,NULL,&da);CHKERRQ(ierr);
-  ierr = DMSetFromOptions(da);CHKERRQ(ierr);
-  ierr = DMSetUp(da);CHKERRQ(ierr);
+  PetscCall(DMDACreate2d(PETSC_COMM_WORLD, DM_BOUNDARY_NONE, DM_BOUNDARY_NONE, DMDA_STENCIL_STAR, 8, 7, PETSC_DECIDE, PETSC_DECIDE, 1, 1, NULL, NULL, &da));
+  PetscCall(DMSetFromOptions(da));
+  PetscCall(DMSetUp(da));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
          Compute the matrix and right-hand-side vector that define
@@ -57,7 +49,7 @@ int main(int argc,char **argv)
      Create parallel matrix preallocated according to the DMDA, format AIJ by default.
      To use symmetric storage, run with -dm_mat_type sbaij -mat_ignore_lower_triangular
   */
-  ierr = DMCreateMatrix(da,&A);CHKERRQ(ierr);
+  PetscCall(DMCreateMatrix(da, &A));
 
   /*
      Set matrix elements for the 2-D, five-point stencil in parallel.
@@ -67,23 +59,42 @@ int main(int argc,char **argv)
       - Rows and columns are specified by the stencil
       - Entries are normalized for a domain [0,1]x[0,1]
    */
-  ierr = PetscLogStageRegister("Assembly", &stage);CHKERRQ(ierr);
-  ierr = PetscLogStagePush(stage);CHKERRQ(ierr);
-  ierr = DMDAGetLocalInfo(da,&info);CHKERRQ(ierr);
-  for (j=info.ys; j<info.ys+info.ym; j++) {
-    for (i=info.xs; i<info.xs+info.xm; i++) {
-      PetscReal   hx  = 1./info.mx,hy = 1./info.my;
-      MatStencil  row = {0},col[5] = {{0}};
+  PetscCall(PetscLogStageRegister("Assembly", &stage));
+  PetscCall(PetscLogStagePush(stage));
+  PetscCall(DMDAGetLocalInfo(da, &info));
+  for (j = info.ys; j < info.ys + info.ym; j++) {
+    for (i = info.xs; i < info.xs + info.xm; i++) {
+      PetscReal   hx = 1. / info.mx, hy = 1. / info.my;
+      MatStencil  row = {0}, col[5] = {{0}};
       PetscScalar v[5];
       PetscInt    ncols = 0;
-      row.j        = j; row.i = i;
-      col[ncols].j = j; col[ncols].i = i; v[ncols++] = 2*(hx/hy + hy/hx);
+      row.j             = j;
+      row.i             = i;
+      col[ncols].j      = j;
+      col[ncols].i      = i;
+      v[ncols++]        = 2 * (hx / hy + hy / hx);
       /* boundaries */
-      if (i>0)         {col[ncols].j = j;   col[ncols].i = i-1; v[ncols++] = -hy/hx;}
-      if (i<info.mx-1) {col[ncols].j = j;   col[ncols].i = i+1; v[ncols++] = -hy/hx;}
-      if (j>0)         {col[ncols].j = j-1; col[ncols].i = i;   v[ncols++] = -hx/hy;}
-      if (j<info.my-1) {col[ncols].j = j+1; col[ncols].i = i;   v[ncols++] = -hx/hy;}
-      ierr = MatSetValuesStencil(A,1,&row,ncols,col,v,INSERT_VALUES);CHKERRQ(ierr);
+      if (i > 0) {
+        col[ncols].j = j;
+        col[ncols].i = i - 1;
+        v[ncols++]   = -hy / hx;
+      }
+      if (i < info.mx - 1) {
+        col[ncols].j = j;
+        col[ncols].i = i + 1;
+        v[ncols++]   = -hy / hx;
+      }
+      if (j > 0) {
+        col[ncols].j = j - 1;
+        col[ncols].i = i;
+        v[ncols++]   = -hx / hy;
+      }
+      if (j < info.my - 1) {
+        col[ncols].j = j + 1;
+        col[ncols].i = i;
+        v[ncols++]   = -hx / hy;
+      }
+      PetscCall(MatSetValuesStencil(A, 1, &row, ncols, col, v, INSERT_VALUES));
     }
   }
 
@@ -93,16 +104,16 @@ int main(int argc,char **argv)
      Computations can be done while messages are in transition
      by placing code between these two statements.
   */
-  ierr = MatAssemblyBegin(A,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-  ierr = MatAssemblyEnd(A,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-  ierr = PetscLogStagePop();CHKERRQ(ierr);
+  PetscCall(MatAssemblyBegin(A, MAT_FINAL_ASSEMBLY));
+  PetscCall(MatAssemblyEnd(A, MAT_FINAL_ASSEMBLY));
+  PetscCall(PetscLogStagePop());
 
   /*
      Create parallel vectors compatible with the DMDA.
   */
-  ierr = DMCreateGlobalVector(da,&u);CHKERRQ(ierr);
-  ierr = VecDuplicate(u,&b);CHKERRQ(ierr);
-  ierr = VecDuplicate(u,&x);CHKERRQ(ierr);
+  PetscCall(DMCreateGlobalVector(da, &u));
+  PetscCall(VecDuplicate(u, &b));
+  PetscCall(VecDuplicate(u, &x));
 
   /*
      Set exact solution; then compute right-hand-side vector.
@@ -110,23 +121,23 @@ int main(int argc,char **argv)
      elements of 1.0;  Alternatively, using the runtime option
      -random_sol forms a solution vector with random components.
   */
-  ierr = PetscOptionsGetBool(NULL,NULL,"-random_exact_sol",&flg,NULL);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetBool(NULL, NULL, "-random_exact_sol", &flg, NULL));
   if (flg) {
-    ierr = PetscRandomCreate(PETSC_COMM_WORLD,&rctx);CHKERRQ(ierr);
-    ierr = PetscRandomSetFromOptions(rctx);CHKERRQ(ierr);
-    ierr = VecSetRandom(u,rctx);CHKERRQ(ierr);
-    ierr = PetscRandomDestroy(&rctx);CHKERRQ(ierr);
+    PetscCall(PetscRandomCreate(PETSC_COMM_WORLD, &rctx));
+    PetscCall(PetscRandomSetFromOptions(rctx));
+    PetscCall(VecSetRandom(u, rctx));
+    PetscCall(PetscRandomDestroy(&rctx));
   } else {
-    ierr = VecSet(u,1.);CHKERRQ(ierr);
+    PetscCall(VecSet(u, 1.));
   }
-  ierr = MatMult(A,u,b);CHKERRQ(ierr);
+  PetscCall(MatMult(A, u, b));
 
   /*
      View the exact solution vector if desired
   */
-  flg  = PETSC_FALSE;
-  ierr = PetscOptionsGetBool(NULL,NULL,"-view_exact_sol",&flg,NULL);CHKERRQ(ierr);
-  if (flg) {ierr = VecView(u,PETSC_VIEWER_STDOUT_WORLD);CHKERRQ(ierr);}
+  flg = PETSC_FALSE;
+  PetscCall(PetscOptionsGetBool(NULL, NULL, "-view_exact_sol", &flg, NULL));
+  if (flg) PetscCall(VecView(u, PETSC_VIEWER_STDOUT_WORLD));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
                 Create the linear solver and set various options
@@ -135,13 +146,13 @@ int main(int argc,char **argv)
   /*
      Create linear solver context
   */
-  ierr = KSPCreate(PETSC_COMM_WORLD,&ksp);CHKERRQ(ierr);
+  PetscCall(KSPCreate(PETSC_COMM_WORLD, &ksp));
 
   /*
      Set operators. Here the matrix that defines the linear system
      also serves as the preconditioning matrix.
   */
-  ierr = KSPSetOperators(ksp,A,A);CHKERRQ(ierr);
+  PetscCall(KSPSetOperators(ksp, A, A));
 
   /*
     Set runtime options, e.g.,
@@ -150,13 +161,13 @@ int main(int argc,char **argv)
     KSPSetFromOptions() is called _after_ any other customization
     routines.
   */
-  ierr = KSPSetFromOptions(ksp);CHKERRQ(ierr);
+  PetscCall(KSPSetFromOptions(ksp));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
                       Solve the linear system
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  ierr = KSPSolve(ksp,b,x);CHKERRQ(ierr);
+  PetscCall(KSPSolve(ksp, b, x));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
                       Check solution and clean up
@@ -165,27 +176,27 @@ int main(int argc,char **argv)
   /*
      Check the error
   */
-  ierr = VecAXPY(x,-1.,u);CHKERRQ(ierr);
-  ierr = VecNorm(x,NORM_2,&norm);CHKERRQ(ierr);
-  ierr = KSPGetIterationNumber(ksp,&its);CHKERRQ(ierr);
+  PetscCall(VecAXPY(x, -1., u));
+  PetscCall(VecNorm(x, NORM_2, &norm));
+  PetscCall(KSPGetIterationNumber(ksp, &its));
 
   /*
      Print convergence information.  PetscPrintf() produces a single
      print statement from all processes that share a communicator.
      An alternative is PetscFPrintf(), which prints to a file.
   */
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Norm of error %g iterations %D\n",(double)norm,its);CHKERRQ(ierr);
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Norm of error %g iterations %" PetscInt_FMT "\n", (double)norm, its));
 
   /*
      Free work space.  All PETSc objects should be destroyed when they
      are no longer needed.
   */
-  ierr = KSPDestroy(&ksp);CHKERRQ(ierr);
-  ierr = VecDestroy(&u);CHKERRQ(ierr);
-  ierr = VecDestroy(&x);CHKERRQ(ierr);
-  ierr = VecDestroy(&b);CHKERRQ(ierr);
-  ierr = MatDestroy(&A);CHKERRQ(ierr);
-  ierr = DMDestroy(&da);CHKERRQ(ierr);
+  PetscCall(KSPDestroy(&ksp));
+  PetscCall(VecDestroy(&u));
+  PetscCall(VecDestroy(&x));
+  PetscCall(VecDestroy(&b));
+  PetscCall(MatDestroy(&A));
+  PetscCall(DMDestroy(&da));
 
   /*
      Always call PetscFinalize() before exiting a program.  This routine
@@ -193,8 +204,8 @@ int main(int argc,char **argv)
        - provides summary and diagnostic information if certain runtime
          options are chosen (e.g., -log_view).
   */
-  ierr = PetscFinalize();
-  return ierr;
+  PetscCall(PetscFinalize());
+  return 0;
 }
 
 /*TEST
