@@ -29,11 +29,10 @@
 */
 PetscErrorCode MatSolve_LMVMDFP(Mat B, Vec F, Vec dX)
 {
-  Mat_LMVM          *lmvm = (Mat_LMVM*)B->data;
-  Mat_SymBrdn       *ldfp = (Mat_SymBrdn*)lmvm->ctx;
-  PetscErrorCode    ierr;
-  PetscInt          i, j;
-  PetscScalar       yjtqi, sjtyi, ytx, stf, ytq;
+  Mat_LMVM    *lmvm = (Mat_LMVM *)B->data;
+  Mat_SymBrdn *ldfp = (Mat_SymBrdn *)lmvm->ctx;
+  PetscInt     i, j;
+  PetscScalar  yjtqi, sjtyi, ytx, stf, ytq;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(F, VEC_CLASSID, 2);
@@ -44,32 +43,32 @@ PetscErrorCode MatSolve_LMVMDFP(Mat B, Vec F, Vec dX)
   if (ldfp->needQ) {
     /* Start the loop for (Q[k] = (B_k)^{-1} * Y[k]) */
     for (i = 0; i <= lmvm->k; ++i) {
-      ierr = MatSymBrdnApplyJ0Inv(B, lmvm->Y[i], ldfp->Q[i]);CHKERRQ(ierr);
-      for (j = 0; j <= i-1; ++j) {
+      PetscCall(MatSymBrdnApplyJ0Inv(B, lmvm->Y[i], ldfp->Q[i]));
+      for (j = 0; j <= i - 1; ++j) {
         /* Compute the necessary dot products */
-        ierr = VecDotBegin(lmvm->Y[j], ldfp->Q[i], &yjtqi);CHKERRQ(ierr);
-        ierr = VecDotBegin(lmvm->S[j], lmvm->Y[i], &sjtyi);CHKERRQ(ierr);
-        ierr = VecDotEnd(lmvm->Y[j], ldfp->Q[i], &yjtqi);CHKERRQ(ierr);
-        ierr = VecDotEnd(lmvm->S[j], lmvm->Y[i], &sjtyi);CHKERRQ(ierr);
+        PetscCall(VecDotBegin(lmvm->Y[j], ldfp->Q[i], &yjtqi));
+        PetscCall(VecDotBegin(lmvm->S[j], lmvm->Y[i], &sjtyi));
+        PetscCall(VecDotEnd(lmvm->Y[j], ldfp->Q[i], &yjtqi));
+        PetscCall(VecDotEnd(lmvm->S[j], lmvm->Y[i], &sjtyi));
         /* Compute the pure DFP component of the inverse application*/
-        ierr = VecAXPBYPCZ(ldfp->Q[i], -PetscRealPart(yjtqi)/ldfp->ytq[j], PetscRealPart(sjtyi)/ldfp->yts[j], 1.0, ldfp->Q[j], lmvm->S[j]);CHKERRQ(ierr);
+        PetscCall(VecAXPBYPCZ(ldfp->Q[i], -PetscRealPart(yjtqi) / ldfp->ytq[j], PetscRealPart(sjtyi) / ldfp->yts[j], 1.0, ldfp->Q[j], lmvm->S[j]));
       }
-      ierr = VecDot(lmvm->Y[i], ldfp->Q[i], &ytq);CHKERRQ(ierr);
+      PetscCall(VecDot(lmvm->Y[i], ldfp->Q[i], &ytq));
       ldfp->ytq[i] = PetscRealPart(ytq);
     }
     ldfp->needQ = PETSC_FALSE;
   }
 
   /* Start the outer loop (i) for the recursive formula */
-  ierr = MatSymBrdnApplyJ0Inv(B, F, dX);CHKERRQ(ierr);
+  PetscCall(MatSymBrdnApplyJ0Inv(B, F, dX));
   for (i = 0; i <= lmvm->k; ++i) {
     /* Get all the dot products we need */
-    ierr = VecDotBegin(lmvm->Y[i], dX, &ytx);CHKERRQ(ierr);
-    ierr = VecDotBegin(lmvm->S[i], F, &stf);CHKERRQ(ierr);
-    ierr = VecDotEnd(lmvm->Y[i], dX, &ytx);CHKERRQ(ierr);
-    ierr = VecDotEnd(lmvm->S[i], F, &stf);CHKERRQ(ierr);
+    PetscCall(VecDotBegin(lmvm->Y[i], dX, &ytx));
+    PetscCall(VecDotBegin(lmvm->S[i], F, &stf));
+    PetscCall(VecDotEnd(lmvm->Y[i], dX, &ytx));
+    PetscCall(VecDotEnd(lmvm->S[i], F, &stf));
     /* Update dX_{i+1} = (B^{-1})_{i+1} * f */
-    ierr = VecAXPBYPCZ(dX, -PetscRealPart(ytx)/ldfp->ytq[i], PetscRealPart(stf)/ldfp->yts[i], 1.0, ldfp->Q[i], lmvm->S[i]);CHKERRQ(ierr);
+    PetscCall(VecAXPBYPCZ(dX, -PetscRealPart(ytx) / ldfp->ytq[i], PetscRealPart(stf) / ldfp->yts[i], 1.0, ldfp->Q[i], lmvm->S[i]));
   }
   PetscFunctionReturn(0);
 }
@@ -102,35 +101,34 @@ PetscErrorCode MatSolve_LMVMDFP(Mat B, Vec F, Vec dX)
 */
 PetscErrorCode MatMult_LMVMDFP(Mat B, Vec X, Vec Z)
 {
-  Mat_LMVM          *lmvm = (Mat_LMVM*)B->data;
-  Mat_SymBrdn       *ldfp = (Mat_SymBrdn*)lmvm->ctx;
-  PetscErrorCode    ierr;
-  PetscInt          i;
-  PetscReal         *alpha, beta;
-  PetscScalar       ytx, stz;
+  Mat_LMVM    *lmvm = (Mat_LMVM *)B->data;
+  Mat_SymBrdn *ldfp = (Mat_SymBrdn *)lmvm->ctx;
+  PetscInt     i;
+  PetscReal   *alpha, beta;
+  PetscScalar  ytx, stz;
 
   PetscFunctionBegin;
   /* Copy the function into the work vector for the first loop */
-  ierr = VecCopy(X, ldfp->work);CHKERRQ(ierr);
+  PetscCall(VecCopy(X, ldfp->work));
 
   /* Start the first loop */
-  ierr = PetscMalloc1(lmvm->k+1, &alpha);CHKERRQ(ierr);
+  PetscCall(PetscMalloc1(lmvm->k + 1, &alpha));
   for (i = lmvm->k; i >= 0; --i) {
-    ierr = VecDot(lmvm->Y[i], ldfp->work, &ytx);CHKERRQ(ierr);
-    alpha[i] = PetscRealPart(ytx)/ldfp->yts[i];
-    ierr = VecAXPY(ldfp->work, -alpha[i], lmvm->S[i]);CHKERRQ(ierr);
+    PetscCall(VecDot(lmvm->Y[i], ldfp->work, &ytx));
+    alpha[i] = PetscRealPart(ytx) / ldfp->yts[i];
+    PetscCall(VecAXPY(ldfp->work, -alpha[i], lmvm->S[i]));
   }
 
   /* Apply the forward product with initial Jacobian */
-  ierr = MatSymBrdnApplyJ0Fwd(B, ldfp->work, Z);CHKERRQ(ierr);
+  PetscCall(MatSymBrdnApplyJ0Fwd(B, ldfp->work, Z));
 
   /* Start the second loop */
   for (i = 0; i <= lmvm->k; ++i) {
-    ierr = VecDot(lmvm->S[i], Z, &stz);CHKERRQ(ierr);
-    beta = PetscRealPart(stz)/ldfp->yts[i];
-    ierr = VecAXPY(Z, alpha[i]-beta, lmvm->Y[i]);CHKERRQ(ierr);
+    PetscCall(VecDot(lmvm->S[i], Z, &stz));
+    beta = PetscRealPart(stz) / ldfp->yts[i];
+    PetscCall(VecAXPY(Z, alpha[i] - beta, lmvm->Y[i]));
   }
-  ierr = PetscFree(alpha);CHKERRQ(ierr);
+  PetscCall(PetscFree(alpha));
   PetscFunctionReturn(0);
 }
 
@@ -138,26 +136,25 @@ PetscErrorCode MatMult_LMVMDFP(Mat B, Vec X, Vec Z)
 
 static PetscErrorCode MatUpdate_LMVMDFP(Mat B, Vec X, Vec F)
 {
-  Mat_LMVM          *lmvm = (Mat_LMVM*)B->data;
-  Mat_SymBrdn       *ldfp = (Mat_SymBrdn*)lmvm->ctx;
-  Mat_LMVM          *dbase;
-  Mat_DiagBrdn      *dctx;
-  PetscErrorCode    ierr;
-  PetscInt          old_k, i;
-  PetscReal         curvtol;
-  PetscScalar       curvature, ytytmp, ststmp;
+  Mat_LMVM     *lmvm = (Mat_LMVM *)B->data;
+  Mat_SymBrdn  *ldfp = (Mat_SymBrdn *)lmvm->ctx;
+  Mat_LMVM     *dbase;
+  Mat_DiagBrdn *dctx;
+  PetscInt      old_k, i;
+  PetscReal     curvtol;
+  PetscScalar   curvature, ytytmp, ststmp;
 
   PetscFunctionBegin;
   if (!lmvm->m) PetscFunctionReturn(0);
   if (lmvm->prev_set) {
     /* Compute the new (S = X - Xprev) and (Y = F - Fprev) vectors */
-    ierr = VecAYPX(lmvm->Xprev, -1.0, X);CHKERRQ(ierr);
-    ierr = VecAYPX(lmvm->Fprev, -1.0, F);CHKERRQ(ierr);
+    PetscCall(VecAYPX(lmvm->Xprev, -1.0, X));
+    PetscCall(VecAYPX(lmvm->Fprev, -1.0, F));
     /* Test if the updates can be accepted */
-    ierr = VecDotBegin(lmvm->Xprev, lmvm->Fprev, &curvature);CHKERRQ(ierr);
-    ierr = VecDotBegin(lmvm->Xprev, lmvm->Xprev, &ststmp);CHKERRQ(ierr);
-    ierr = VecDotEnd(lmvm->Xprev, lmvm->Fprev, &curvature);CHKERRQ(ierr);
-    ierr = VecDotEnd(lmvm->Xprev, lmvm->Xprev, &ststmp);CHKERRQ(ierr);
+    PetscCall(VecDotBegin(lmvm->Xprev, lmvm->Fprev, &curvature));
+    PetscCall(VecDotBegin(lmvm->Xprev, lmvm->Xprev, &ststmp));
+    PetscCall(VecDotEnd(lmvm->Xprev, lmvm->Fprev, &curvature));
+    PetscCall(VecDotEnd(lmvm->Xprev, lmvm->Xprev, &ststmp));
     if (PetscRealPart(ststmp) < lmvm->eps) {
       curvtol = 0.0;
     } else {
@@ -166,26 +163,24 @@ static PetscErrorCode MatUpdate_LMVMDFP(Mat B, Vec X, Vec F)
     if (PetscRealPart(curvature) > curvtol) {
       /* Update is good, accept it */
       ldfp->watchdog = 0;
-      ldfp->needQ = PETSC_TRUE;
-      old_k = lmvm->k;
-      ierr = MatUpdateKernel_LMVM(B, lmvm->Xprev, lmvm->Fprev);CHKERRQ(ierr);
+      ldfp->needQ    = PETSC_TRUE;
+      old_k          = lmvm->k;
+      PetscCall(MatUpdateKernel_LMVM(B, lmvm->Xprev, lmvm->Fprev));
       /* If we hit the memory limit, shift the yts, yty and sts arrays */
       if (old_k == lmvm->k) {
-        for (i = 0; i <= lmvm->k-1; ++i) {
-          ldfp->yts[i] = ldfp->yts[i+1];
-          ldfp->yty[i] = ldfp->yty[i+1];
-          ldfp->sts[i] = ldfp->sts[i+1];
+        for (i = 0; i <= lmvm->k - 1; ++i) {
+          ldfp->yts[i] = ldfp->yts[i + 1];
+          ldfp->yty[i] = ldfp->yty[i + 1];
+          ldfp->sts[i] = ldfp->sts[i + 1];
         }
       }
       /* Update history of useful scalars */
-      ierr = VecDot(lmvm->Y[lmvm->k], lmvm->Y[lmvm->k], &ytytmp);CHKERRQ(ierr);
+      PetscCall(VecDot(lmvm->Y[lmvm->k], lmvm->Y[lmvm->k], &ytytmp));
       ldfp->yts[lmvm->k] = PetscRealPart(curvature);
       ldfp->yty[lmvm->k] = PetscRealPart(ytytmp);
       ldfp->sts[lmvm->k] = PetscRealPart(ststmp);
       /* Compute the scalar scale if necessary */
-      if (ldfp->scale_type == MAT_LMVM_SYMBROYDEN_SCALE_SCALAR) {
-        ierr = MatSymBrdnComputeJ0Scalar(B);CHKERRQ(ierr);
-      }
+      if (ldfp->scale_type == MAT_LMVM_SYMBROYDEN_SCALE_SCALAR) PetscCall(MatSymBrdnComputeJ0Scalar(B));
     } else {
       /* Update is bad, skip it */
       ++lmvm->nrejects;
@@ -194,9 +189,9 @@ static PetscErrorCode MatUpdate_LMVMDFP(Mat B, Vec X, Vec F)
   } else {
     switch (ldfp->scale_type) {
     case MAT_LMVM_SYMBROYDEN_SCALE_DIAGONAL:
-      dbase = (Mat_LMVM*)ldfp->D->data;
-      dctx = (Mat_DiagBrdn*)dbase->ctx;
-      ierr = VecSet(dctx->invD, ldfp->delta);CHKERRQ(ierr);
+      dbase = (Mat_LMVM *)ldfp->D->data;
+      dctx  = (Mat_DiagBrdn *)dbase->ctx;
+      PetscCall(VecSet(dctx->invD, ldfp->delta));
       break;
     case MAT_LMVM_SYMBROYDEN_SCALE_SCALAR:
       ldfp->sigma = ldfp->delta;
@@ -210,20 +205,16 @@ static PetscErrorCode MatUpdate_LMVMDFP(Mat B, Vec X, Vec F)
   }
 
   /* Update the scaling */
-  if (ldfp->scale_type == MAT_LMVM_SYMBROYDEN_SCALE_DIAGONAL) {
-    ierr = MatLMVMUpdate(ldfp->D, X, F);CHKERRQ(ierr);
-  }
+  if (ldfp->scale_type == MAT_LMVM_SYMBROYDEN_SCALE_DIAGONAL) PetscCall(MatLMVMUpdate(ldfp->D, X, F));
 
   if (ldfp->watchdog > ldfp->max_seq_rejects) {
-    ierr = MatLMVMReset(B, PETSC_FALSE);CHKERRQ(ierr);
-    if (ldfp->scale_type == MAT_LMVM_SYMBROYDEN_SCALE_DIAGONAL) {
-      ierr = MatLMVMReset(ldfp->D, PETSC_FALSE);CHKERRQ(ierr);
-    }
+    PetscCall(MatLMVMReset(B, PETSC_FALSE));
+    if (ldfp->scale_type == MAT_LMVM_SYMBROYDEN_SCALE_DIAGONAL) PetscCall(MatLMVMReset(ldfp->D, PETSC_FALSE));
   }
 
   /* Save the solution and function to be used in the next update */
-  ierr = VecCopy(X, lmvm->Xprev);CHKERRQ(ierr);
-  ierr = VecCopy(F, lmvm->Fprev);CHKERRQ(ierr);
+  PetscCall(VecCopy(X, lmvm->Xprev));
+  PetscCall(VecCopy(F, lmvm->Fprev));
   lmvm->prev_set = PETSC_TRUE;
   PetscFunctionReturn(0);
 }
@@ -232,19 +223,18 @@ static PetscErrorCode MatUpdate_LMVMDFP(Mat B, Vec X, Vec F)
 
 static PetscErrorCode MatCopy_LMVMDFP(Mat B, Mat M, MatStructure str)
 {
-  Mat_LMVM          *bdata = (Mat_LMVM*)B->data;
-  Mat_SymBrdn       *bctx = (Mat_SymBrdn*)bdata->ctx;
-  Mat_LMVM          *mdata = (Mat_LMVM*)M->data;
-  Mat_SymBrdn       *mctx = (Mat_SymBrdn*)mdata->ctx;
-  PetscErrorCode    ierr;
-  PetscInt          i;
+  Mat_LMVM    *bdata = (Mat_LMVM *)B->data;
+  Mat_SymBrdn *bctx  = (Mat_SymBrdn *)bdata->ctx;
+  Mat_LMVM    *mdata = (Mat_LMVM *)M->data;
+  Mat_SymBrdn *mctx  = (Mat_SymBrdn *)mdata->ctx;
+  PetscInt     i;
 
   PetscFunctionBegin;
   mctx->needQ = bctx->needQ;
-  for (i=0; i<=bdata->k; ++i) {
+  for (i = 0; i <= bdata->k; ++i) {
     mctx->ytq[i] = bctx->ytq[i];
     mctx->yts[i] = bctx->yts[i];
-    ierr = VecCopy(bctx->Q[i], mctx->Q[i]);CHKERRQ(ierr);
+    PetscCall(VecCopy(bctx->Q[i], mctx->Q[i]));
   }
   mctx->scale_type      = bctx->scale_type;
   mctx->alpha           = bctx->alpha;
@@ -258,7 +248,7 @@ static PetscErrorCode MatCopy_LMVMDFP(Mat B, Mat M, MatStructure str)
     mctx->sigma = bctx->sigma;
     break;
   case MAT_LMVM_SYMBROYDEN_SCALE_DIAGONAL:
-    ierr = MatCopy(bctx->D, mctx->D, SAME_NONZERO_PATTERN);CHKERRQ(ierr);
+    PetscCall(MatCopy(bctx->D, mctx->D, SAME_NONZERO_PATTERN));
     break;
   case MAT_LMVM_SYMBROYDEN_SCALE_NONE:
     mctx->sigma = 1.0;
@@ -273,23 +263,22 @@ static PetscErrorCode MatCopy_LMVMDFP(Mat B, Mat M, MatStructure str)
 
 static PetscErrorCode MatReset_LMVMDFP(Mat B, PetscBool destructive)
 {
-  Mat_LMVM          *lmvm = (Mat_LMVM*)B->data;
-  Mat_SymBrdn       *ldfp = (Mat_SymBrdn*)lmvm->ctx;
-  Mat_LMVM          *dbase;
-  Mat_DiagBrdn      *dctx;
-  PetscErrorCode    ierr;
+  Mat_LMVM     *lmvm = (Mat_LMVM *)B->data;
+  Mat_SymBrdn  *ldfp = (Mat_SymBrdn *)lmvm->ctx;
+  Mat_LMVM     *dbase;
+  Mat_DiagBrdn *dctx;
 
   PetscFunctionBegin;
   ldfp->watchdog = 0;
-  ldfp->needQ = PETSC_TRUE;
+  ldfp->needQ    = PETSC_TRUE;
   if (ldfp->allocated) {
     if (destructive) {
-      ierr = VecDestroy(&ldfp->work);CHKERRQ(ierr);
-      ierr = PetscFree4(ldfp->ytq, ldfp->yts, ldfp->yty, ldfp->sts);CHKERRQ(ierr);
-      ierr = VecDestroyVecs(lmvm->m, &ldfp->Q);CHKERRQ(ierr);
+      PetscCall(VecDestroy(&ldfp->work));
+      PetscCall(PetscFree4(ldfp->ytq, ldfp->yts, ldfp->yty, ldfp->sts));
+      PetscCall(VecDestroyVecs(lmvm->m, &ldfp->Q));
       switch (ldfp->scale_type) {
       case MAT_LMVM_SYMBROYDEN_SCALE_DIAGONAL:
-        ierr = MatLMVMReset(ldfp->D, PETSC_TRUE);CHKERRQ(ierr);
+        PetscCall(MatLMVMReset(ldfp->D, PETSC_TRUE));
         break;
       default:
         break;
@@ -301,10 +290,10 @@ static PetscErrorCode MatReset_LMVMDFP(Mat B, PetscBool destructive)
         ldfp->sigma = ldfp->delta;
         break;
       case MAT_LMVM_SYMBROYDEN_SCALE_DIAGONAL:
-        ierr = MatLMVMReset(ldfp->D, PETSC_FALSE);CHKERRQ(ierr);
-        dbase = (Mat_LMVM*)ldfp->D->data;
-        dctx = (Mat_DiagBrdn*)dbase->ctx;
-        ierr = VecSet(dctx->invD, ldfp->delta);CHKERRQ(ierr);
+        PetscCall(MatLMVMReset(ldfp->D, PETSC_FALSE));
+        dbase = (Mat_LMVM *)ldfp->D->data;
+        dctx  = (Mat_DiagBrdn *)dbase->ctx;
+        PetscCall(VecSet(dctx->invD, ldfp->delta));
         break;
       case MAT_LMVM_SYMBROYDEN_SCALE_NONE:
         ldfp->sigma = 1.0;
@@ -314,7 +303,7 @@ static PetscErrorCode MatReset_LMVMDFP(Mat B, PetscBool destructive)
       }
     }
   }
-  ierr = MatReset_LMVM(B, destructive);CHKERRQ(ierr);
+  PetscCall(MatReset_LMVM(B, destructive));
   PetscFunctionReturn(0);
 }
 
@@ -322,21 +311,18 @@ static PetscErrorCode MatReset_LMVMDFP(Mat B, PetscBool destructive)
 
 static PetscErrorCode MatAllocate_LMVMDFP(Mat B, Vec X, Vec F)
 {
-  Mat_LMVM          *lmvm = (Mat_LMVM*)B->data;
-  Mat_SymBrdn       *ldfp = (Mat_SymBrdn*)lmvm->ctx;
-  PetscErrorCode    ierr;
+  Mat_LMVM    *lmvm = (Mat_LMVM *)B->data;
+  Mat_SymBrdn *ldfp = (Mat_SymBrdn *)lmvm->ctx;
 
   PetscFunctionBegin;
-  ierr = MatAllocate_LMVM(B, X, F);CHKERRQ(ierr);
+  PetscCall(MatAllocate_LMVM(B, X, F));
   if (!ldfp->allocated) {
-    ierr = VecDuplicate(X, &ldfp->work);CHKERRQ(ierr);
-    ierr = PetscMalloc4(lmvm->m, &ldfp->ytq, lmvm->m, &ldfp->yts, lmvm->m, &ldfp->yty, lmvm->m, &ldfp->sts);CHKERRQ(ierr);
-    if (lmvm->m > 0) {
-      ierr = VecDuplicateVecs(X, lmvm->m, &ldfp->Q);CHKERRQ(ierr);
-    }
+    PetscCall(VecDuplicate(X, &ldfp->work));
+    PetscCall(PetscMalloc4(lmvm->m, &ldfp->ytq, lmvm->m, &ldfp->yts, lmvm->m, &ldfp->yty, lmvm->m, &ldfp->sts));
+    if (lmvm->m > 0) PetscCall(VecDuplicateVecs(X, lmvm->m, &ldfp->Q));
     switch (ldfp->scale_type) {
     case MAT_LMVM_SYMBROYDEN_SCALE_DIAGONAL:
-      ierr = MatLMVMAllocate(ldfp->D, X, F);CHKERRQ(ierr);
+      PetscCall(MatLMVMAllocate(ldfp->D, X, F));
       break;
     default:
       break;
@@ -350,20 +336,19 @@ static PetscErrorCode MatAllocate_LMVMDFP(Mat B, Vec X, Vec F)
 
 static PetscErrorCode MatDestroy_LMVMDFP(Mat B)
 {
-  Mat_LMVM          *lmvm = (Mat_LMVM*)B->data;
-  Mat_SymBrdn       *ldfp = (Mat_SymBrdn*)lmvm->ctx;
-  PetscErrorCode    ierr;
+  Mat_LMVM    *lmvm = (Mat_LMVM *)B->data;
+  Mat_SymBrdn *ldfp = (Mat_SymBrdn *)lmvm->ctx;
 
   PetscFunctionBegin;
   if (ldfp->allocated) {
-    ierr = VecDestroy(&ldfp->work);CHKERRQ(ierr);
-    ierr = PetscFree4(ldfp->ytq, ldfp->yts, ldfp->yty, ldfp->sts);CHKERRQ(ierr);
-    ierr = VecDestroyVecs(lmvm->m, &ldfp->Q);CHKERRQ(ierr);
+    PetscCall(VecDestroy(&ldfp->work));
+    PetscCall(PetscFree4(ldfp->ytq, ldfp->yts, ldfp->yty, ldfp->sts));
+    PetscCall(VecDestroyVecs(lmvm->m, &ldfp->Q));
     ldfp->allocated = PETSC_FALSE;
   }
-  ierr = MatDestroy(&ldfp->D);CHKERRQ(ierr);
-  ierr = PetscFree(lmvm->ctx);CHKERRQ(ierr);
-  ierr = MatDestroy_LMVM(B);CHKERRQ(ierr);
+  PetscCall(MatDestroy(&ldfp->D));
+  PetscCall(PetscFree(lmvm->ctx));
+  PetscCall(MatDestroy_LMVM(B));
   PetscFunctionReturn(0);
 }
 
@@ -371,25 +356,22 @@ static PetscErrorCode MatDestroy_LMVMDFP(Mat B)
 
 static PetscErrorCode MatSetUp_LMVMDFP(Mat B)
 {
-  Mat_LMVM          *lmvm = (Mat_LMVM*)B->data;
-  Mat_SymBrdn       *ldfp = (Mat_SymBrdn*)lmvm->ctx;
-  PetscErrorCode    ierr;
-  PetscInt          n, N;
+  Mat_LMVM    *lmvm = (Mat_LMVM *)B->data;
+  Mat_SymBrdn *ldfp = (Mat_SymBrdn *)lmvm->ctx;
+  PetscInt     n, N;
 
   PetscFunctionBegin;
-  ierr = MatSetUp_LMVM(B);CHKERRQ(ierr);
+  PetscCall(MatSetUp_LMVM(B));
   if (!ldfp->allocated) {
-    ierr = VecDuplicate(lmvm->Xprev, &ldfp->work);CHKERRQ(ierr);
-    ierr = PetscMalloc4(lmvm->m, &ldfp->ytq, lmvm->m, &ldfp->yts, lmvm->m, &ldfp->yty, lmvm->m, &ldfp->sts);CHKERRQ(ierr);
-    if (lmvm->m > 0) {
-      ierr = VecDuplicateVecs(lmvm->Xprev, lmvm->m, &ldfp->Q);CHKERRQ(ierr);
-    }
+    PetscCall(VecDuplicate(lmvm->Xprev, &ldfp->work));
+    PetscCall(PetscMalloc4(lmvm->m, &ldfp->ytq, lmvm->m, &ldfp->yts, lmvm->m, &ldfp->yty, lmvm->m, &ldfp->sts));
+    if (lmvm->m > 0) PetscCall(VecDuplicateVecs(lmvm->Xprev, lmvm->m, &ldfp->Q));
     switch (ldfp->scale_type) {
     case MAT_LMVM_SYMBROYDEN_SCALE_DIAGONAL:
-      ierr = MatGetLocalSize(B, &n, &n);CHKERRQ(ierr);
-      ierr = MatGetSize(B, &N, &N);CHKERRQ(ierr);
-      ierr = MatSetSizes(ldfp->D, n, n, N, N);CHKERRQ(ierr);
-      ierr = MatSetUp(ldfp->D);CHKERRQ(ierr);
+      PetscCall(MatGetLocalSize(B, &n, &n));
+      PetscCall(MatGetSize(B, &N, &N));
+      PetscCall(MatSetSizes(ldfp->D, n, n, N, N));
+      PetscCall(MatSetUp(ldfp->D));
       break;
     default:
       break;
@@ -401,15 +383,13 @@ static PetscErrorCode MatSetUp_LMVMDFP(Mat B)
 
 /*------------------------------------------------------------*/
 
-static PetscErrorCode MatSetFromOptions_LMVMDFP(PetscOptionItems *PetscOptionsObject, Mat B)
+static PetscErrorCode MatSetFromOptions_LMVMDFP(Mat B, PetscOptionItems *PetscOptionsObject)
 {
-  PetscErrorCode               ierr;
-
   PetscFunctionBegin;
-  ierr = MatSetFromOptions_LMVM(PetscOptionsObject, B);CHKERRQ(ierr);
-  ierr = PetscOptionsHead(PetscOptionsObject,"DFP method for approximating SPD Jacobian actions (MATLMVMDFP)");CHKERRQ(ierr);
-  ierr = MatSetFromOptions_LMVMSymBrdn_Private(PetscOptionsObject, B);CHKERRQ(ierr);
-  ierr = PetscOptionsTail();CHKERRQ(ierr);
+  PetscCall(MatSetFromOptions_LMVM(B, PetscOptionsObject));
+  PetscOptionsHeadBegin(PetscOptionsObject, "DFP method for approximating SPD Jacobian actions (MATLMVMDFP)");
+  PetscCall(MatSetFromOptions_LMVMSymBrdn_Private(B, PetscOptionsObject));
+  PetscOptionsHeadEnd();
   PetscFunctionReturn(0);
 }
 
@@ -417,28 +397,27 @@ static PetscErrorCode MatSetFromOptions_LMVMDFP(PetscOptionItems *PetscOptionsOb
 
 PetscErrorCode MatCreate_LMVMDFP(Mat B)
 {
-  Mat_LMVM          *lmvm;
-  Mat_SymBrdn       *ldfp;
-  PetscErrorCode    ierr;
+  Mat_LMVM    *lmvm;
+  Mat_SymBrdn *ldfp;
 
   PetscFunctionBegin;
-  ierr = MatCreate_LMVMSymBrdn(B);CHKERRQ(ierr);
-  ierr = PetscObjectChangeTypeName((PetscObject)B, MATLMVMDFP);CHKERRQ(ierr);
-  B->ops->setup = MatSetUp_LMVMDFP;
-  B->ops->destroy = MatDestroy_LMVMDFP;
+  PetscCall(MatCreate_LMVMSymBrdn(B));
+  PetscCall(PetscObjectChangeTypeName((PetscObject)B, MATLMVMDFP));
+  B->ops->setup          = MatSetUp_LMVMDFP;
+  B->ops->destroy        = MatDestroy_LMVMDFP;
   B->ops->setfromoptions = MatSetFromOptions_LMVMDFP;
-  B->ops->solve = MatSolve_LMVMDFP;
+  B->ops->solve          = MatSolve_LMVMDFP;
 
-  lmvm = (Mat_LMVM*)B->data;
+  lmvm                = (Mat_LMVM *)B->data;
   lmvm->ops->allocate = MatAllocate_LMVMDFP;
-  lmvm->ops->reset = MatReset_LMVMDFP;
-  lmvm->ops->update = MatUpdate_LMVMDFP;
-  lmvm->ops->mult = MatMult_LMVMDFP;
-  lmvm->ops->copy = MatCopy_LMVMDFP;
+  lmvm->ops->reset    = MatReset_LMVMDFP;
+  lmvm->ops->update   = MatUpdate_LMVMDFP;
+  lmvm->ops->mult     = MatMult_LMVMDFP;
+  lmvm->ops->copy     = MatCopy_LMVMDFP;
 
-  ldfp = (Mat_SymBrdn*)lmvm->ctx;
-  ldfp->needP           = PETSC_FALSE;
-  ldfp->phi             = 1.0;
+  ldfp        = (Mat_SymBrdn *)lmvm->ctx;
+  ldfp->needP = PETSC_FALSE;
+  ldfp->phi   = 1.0;
   PetscFunctionReturn(0);
 }
 
@@ -450,29 +429,25 @@ PetscErrorCode MatCreate_LMVMDFP(Mat B)
    construction, and is the dual of L-BFGS where Y and S vectors swap roles.
 
    The provided local and global sizes must match the solution and function vectors
-   used with MatLMVMUpdate() and MatSolve(). The resulting L-DFP matrix will have
-   storage vectors allocated with VecCreateSeq() in serial and VecCreateMPI() in
+   used with `MatLMVMUpdate()` and `MatSolve()`. The resulting L-DFP matrix will have
+   storage vectors allocated with `VecCreateSeq()` in serial and `VecCreateMPI()` in
    parallel. To use the L-DFP matrix with other vector types, the matrix must be
-   created using MatCreate() and MatSetType(), followed by MatLMVMAllocate().
+   created using `MatCreate()` and `MatSetType()`, followed by `MatLMVMAllocate()`.
    This ensures that the internal storage and work vectors are duplicated from the
    correct type of vector.
 
    Collective
 
    Input Parameters:
-+  comm - MPI communicator, set to PETSC_COMM_SELF
++  comm - MPI communicator
 .  n - number of local rows for storage vectors
 -  N - global size of the storage vectors
 
    Output Parameter:
 .  B - the matrix
 
-   It is recommended that one use the MatCreate(), MatSetType() and/or MatSetFromOptions()
-   paradigm instead of this routine directly.
-
    Options Database Keys:
-+   -mat_lmvm_num_vecs - maximum number of correction vectors (i.e.: updates) stored
-.   -mat_lmvm_scale_type - (developer) type of scaling applied to J0 (none, scalar, diagonal)
++   -mat_lmvm_scale_type - (developer) type of scaling applied to J0 (none, scalar, diagonal)
 .   -mat_lmvm_theta - (developer) convex ratio between BFGS and DFP components of the diagonal J0 scaling
 .   -mat_lmvm_rho - (developer) update limiter for the J0 scaling
 .   -mat_lmvm_alpha - (developer) coefficient factor for the quadratic subproblem in J0 scaling
@@ -481,17 +456,19 @@ PetscErrorCode MatCreate_LMVMDFP(Mat B)
 
    Level: intermediate
 
-.seealso: MatCreate(), MATLMVM, MATLMVMDFP, MatCreateLMVMBFGS(), MatCreateLMVMSR1(),
-           MatCreateLMVMBrdn(), MatCreateLMVMBadBrdn(), MatCreateLMVMSymBrdn()
+   Note:
+   It is recommended that one use the `MatCreate()`, `MatSetType()` and/or `MatSetFromOptions()`
+   paradigm instead of this routine directly.
+
+.seealso: [](chapter_ksp), `MatCreate()`, `MATLMVM`, `MATLMVMDFP`, `MatCreateLMVMBFGS()`, `MatCreateLMVMSR1()`,
+          `MatCreateLMVMBrdn()`, `MatCreateLMVMBadBrdn()`, `MatCreateLMVMSymBrdn()`
 @*/
 PetscErrorCode MatCreateLMVMDFP(MPI_Comm comm, PetscInt n, PetscInt N, Mat *B)
 {
-  PetscErrorCode    ierr;
-
   PetscFunctionBegin;
-  ierr = MatCreate(comm, B);CHKERRQ(ierr);
-  ierr = MatSetSizes(*B, n, n, N, N);CHKERRQ(ierr);
-  ierr = MatSetType(*B, MATLMVMDFP);CHKERRQ(ierr);
-  ierr = MatSetUp(*B);CHKERRQ(ierr);
+  PetscCall(MatCreate(comm, B));
+  PetscCall(MatSetSizes(*B, n, n, N, N));
+  PetscCall(MatSetType(*B, MATLMVMDFP));
+  PetscCall(MatSetUp(*B));
   PetscFunctionReturn(0);
 }
