@@ -2,9 +2,9 @@
    Private context for Richardson iteration
 */
 
-#if !defined(__SNES_RICHARDSON_H)
+#ifndef __SNES_RICHARDSON_H
 #define __SNES_RICHARDSON_H
-#include <petsc-private/snesimpl.h>
+#include <petsc/private/snesimpl.h>
 
 typedef struct {
   int dummy;
