@@ -16,10 +16,10 @@
 #define snesgetoptionsprefix_            SNESGETOPTIONSPREFIX
 #define snesgettype_                     SNESGETTYPE
 #define snessetfunction_                 SNESSETFUNCTION
-#define snessetngs_                       SNESSETNGS
-#define snessetupdate_                    SNESSETUPDATE
+#define snessetngs_                      SNESSETNGS
+#define snessetupdate_                   SNESSETUPDATE
 #define snesgetfunction_                 SNESGETFUNCTION
-#define snesgetngs_                       SNESGETNGS
+#define snesgetngs_                      SNESGETNGS
 #define snessetconvergencetest_          SNESSETCONVERGENCETEST
 #define snesconvergeddefault_            SNESCONVERGEDDEFAULT
 #define snesconvergedskip_               SNESCONVERGEDSKIP
@@ -35,6 +35,8 @@
 #define snesmonitorset_                  SNESMONITORSET
 #define snesnewtontrsetprecheck_         SNESNEWTONTRSETPRECHECK
 #define snesnewtontrsetpostcheck_        SNESNEWTONTRSETPOSTCHECK
+#define snesnewtontrdcsetprecheck_       SNESNEWTONTRDCSETPRECHECK
+#define snesnewtontrdcsetpostcheck_      SNESNEWTONTRDCSETPOSTCHECK
 #define snesviewfromoptions_             SNESVIEWFROMOPTIONS
 #define snesgetconvergedreasonstring_    SNESGETCONVERGEDREASONSTRING
 #elif !defined(PETSC_HAVE_FORTRAN_UNDERSCORE)
@@ -69,6 +71,8 @@
 #define snesmonitorset_                  snesmonitorset
 #define snesnewtontrsetprecheck_         snesnewtontrsetprecheck
 #define snesnewtontrsetpostcheck_        snesnewtontrsetpostcheck
+#define snesnewtontrdcsetprecheck_       snesnewtontrdcsetprecheck
+#define snesnewtontrdcsetpostcheck_      snesnewtontrdcsetpostcheck
 #define snesviewfromoptions_             snesviewfromoptions
 #define snesgetconvergedreasonstring_    snesgetconvergedreasonstring
 #endif
@@ -109,6 +113,15 @@ PETSC_EXTERN void snesnewtontrsetprecheck_(SNES *snes, void (*func)(SNES,Vec,Vec
   SNESNewtonTRSetPreCheck(*snes,ourtrprecheckfunction,NULL);
 }
 
+PETSC_EXTERN void snesnewtontrdcsetprecheck_(SNES *snes, void (*func)(SNES,Vec,Vec,PetscBool*,void*),void *ctx,PetscErrorCode *ierr PETSC_F90_2PTR_PROTO(ptr))
+{
+  *ierr = PetscObjectSetFortranCallback((PetscObject)*snes,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.trprecheck,(PetscVoidFunction)func,ctx);if (*ierr) return;
+#if defined(PETSC_HAVE_F90_2PTR_ARG)
+  *ierr = PetscObjectSetFortranCallback((PetscObject)*snes,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.trprecheck_pgiptr,NULL,ptr);if (*ierr) return;
+#endif
+  SNESNewtonTRDCSetPreCheck(*snes,ourtrprecheckfunction,NULL);
+}
+
 static PetscErrorCode ourtrpostcheckfunction(SNES snes,Vec x,Vec y,Vec w,PetscBool *changed_y,PetscBool *changed_w,void *ctx)
 {
 #if defined(PETSC_HAVE_F90_2PTR_ARG)
@@ -127,6 +140,15 @@ PETSC_EXTERN void snesnewtontrsetpostcheck_(SNES *snes, void (*func)(SNES,Vec,Ve
   SNESNewtonTRSetPostCheck(*snes,ourtrpostcheckfunction,NULL);
 }
 
+PETSC_EXTERN void snesnewtontrdcsetpostcheck_(SNES *snes, void (*func)(SNES,Vec,Vec,Vec,PetscBool*,PetscBool*,void*),void *ctx,PetscErrorCode *ierr PETSC_F90_2PTR_PROTO(ptr))
+{
+  *ierr = PetscObjectSetFortranCallback((PetscObject)*snes,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.trpostcheck,(PetscVoidFunction)func,ctx);if (*ierr) return;
+#if defined(PETSC_HAVE_F90_2PTR_ARG)
+  *ierr = PetscObjectSetFortranCallback((PetscObject)*snes,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.trpostcheck_pgiptr,NULL,ptr);if (*ierr) return;
+#endif
+  SNESNewtonTRDCSetPostCheck(*snes,ourtrpostcheckfunction,NULL);
+}
+
 static PetscErrorCode oursnesfunction(SNES snes,Vec x,Vec f,void *ctx)
 {
 #if defined(PETSC_HAVE_F90_2PTR_ARG)
@@ -169,7 +191,6 @@ static PetscErrorCode ourmondestroy(void **ctx)
   PetscObjectUseFortranCallback(snes,_cb.mondestroy,(void*,PetscErrorCode*),(_ctx,&ierr));
 }
 
-/* ---------------------------------------------------------*/
 /*
      snescomputejacobiandefault() and snescomputejacobiandefaultcolor()
   These can be used directly from Fortran but are mostly so that
@@ -220,7 +241,7 @@ PETSC_EXTERN void snessetjacobian2_(SNES *snes,Mat *A,Mat *B,
 {
   snessetjacobian_(snes,A,B,func,ctx,ierr);
 }
-/* -------------------------------------------------------------*/
+
 static PetscErrorCode oursnespicardfunction(SNES snes,Vec x,Vec f,void *ctx)
 {
 #if defined(PETSC_HAVE_F90_2PTR_ARG)
@@ -245,7 +266,6 @@ PETSC_EXTERN void snessetpicard_(SNES *snes,Vec *r,void (*func)(SNES*,Vec*,Vec *
     *ierr = PetscObjectSetFortranCallback((PetscObject)*snes,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.jacobian,(PetscVoidFunction)J,ctx);
     if (!*ierr) *ierr = SNESSetPicard(*snes,*r,oursnespicardfunction,*A,*B,oursnespicardjacobian,NULL);
 }
-/* -------------------------------------------------------------*/
 
 PETSC_EXTERN void snesgetoptionsprefix_(SNES *snes,char* prefix,PetscErrorCode *ierr,PETSC_FORTRAN_CHARLEN_T len)
 {
@@ -265,8 +285,6 @@ PETSC_EXTERN void snesgettype_(SNES *snes,char* name, PetscErrorCode *ierr,PETSC
   FIXRETURNCHAR(PETSC_TRUE,name,len);
 }
 
-/* ---------------------------------------------------------*/
-
 /*
    These are not usually called from Fortran but allow Fortran users
    to transparently set these monitors from .F code
@@ -291,7 +309,6 @@ PETSC_EXTERN void snessetupdate_(SNES *snes,void (*func)(SNES*,PetscInt*,PetscEr
   *ierr = PetscObjectSetFortranCallback((PetscObject)*snes,PETSC_FORTRAN_CALLBACK_CLASS,&_cb.update,(PetscVoidFunction)func,NULL);if (*ierr) return;
   *ierr = SNESSetUpdate(*snes,oursnesupdate);
 }
-/* ---------------------------------------------------------*/
 
 /* the func argument is ignored */
 PETSC_EXTERN void snesgetfunction_(SNES *snes,Vec *r,void (*func)(SNES,Vec,Vec,void*),void **ctx,PetscErrorCode *ierr)
@@ -307,8 +324,6 @@ PETSC_EXTERN void snesgetngs_(SNES *snes,void *func,void **ctx,PetscErrorCode *i
   *ierr = PetscObjectGetFortranCallback((PetscObject)*snes,PETSC_FORTRAN_CALLBACK_CLASS,_cb.ngs,NULL,ctx);
 }
 
-/*----------------------------------------------------------------------*/
-
 PETSC_EXTERN void snesconvergeddefault_(SNES *snes,PetscInt *it,PetscReal *a,PetscReal *b,PetscReal *c,SNESConvergedReason *r, void *ct,PetscErrorCode *ierr)
 {
   *ierr = SNESConvergedDefault(*snes,*it,*a,*b,*c,r,ct);
@@ -333,7 +348,6 @@ PETSC_EXTERN void snessetconvergencetest_(SNES *snes,void (*func)(SNES*,PetscInt
     *ierr = SNESSetConvergenceTest(*snes,oursnestest,*snes,ourdestroy);
   }
 }
-/*----------------------------------------------------------------------*/
 
 PETSC_EXTERN void snesview_(SNES *snes,PetscViewer *viewer, PetscErrorCode *ierr)
 {
@@ -385,8 +399,6 @@ PETSC_EXTERN void snessetoptionsprefix_(SNES *snes,char* prefix,PetscErrorCode *
   FREECHAR(prefix,t);
 }
 
-/*----------------------------------------------------------------------*/
-
 PETSC_EXTERN void snesmonitordefault_(SNES *snes,PetscInt *its,PetscReal *fgnorm,PetscViewerAndFormat **dummy,PetscErrorCode *ierr)
 {
   *ierr = SNESMonitorDefault(*snes,*its,*fgnorm,*dummy);
