@@ -6,12 +6,7 @@ This example also illustrates the use of matrix coloring.  Runtime options inclu
   -mx <xg>, where <xg> = number of grid points in the x-direction\n\
   -my <yg>, where <yg> = number of grid points in the y-direction\n\n";
 
-/*T
-   Concepts: SNES^sequential Bratu example
-   Processors: 1
-T*/
-
-/* ------------------------------------------------------------------------
+/*
 
     Solid Fuel Ignition (SFI) problem.  This problem is modeled by
     the partial differential equation
@@ -28,7 +23,7 @@ T*/
 
     The parallel version of this code is snes/tutorials/ex5.c
 
-  ------------------------------------------------------------------------- */
+*/
 
 /*
    Include "petscsnes.h" so that we can use SNES solvers.  Note that
@@ -48,71 +43,73 @@ T*/
    FormFunction().
 */
 typedef struct {
-  PetscReal param;              /* test problem parameter */
-  PetscInt  mx;                 /* Discretization in x-direction */
-  PetscInt  my;                 /* Discretization in y-direction */
+  PetscReal param; /* test problem parameter */
+  PetscInt  mx;    /* Discretization in x-direction */
+  PetscInt  my;    /* Discretization in y-direction */
 } AppCtx;
 
 /*
    User-defined routines
 */
-extern PetscErrorCode FormJacobian(SNES,Vec,Mat,Mat,void*);
-extern PetscErrorCode FormFunction(SNES,Vec,Vec,void*);
-extern PetscErrorCode FormInitialGuess(AppCtx*,Vec);
-extern PetscErrorCode ConvergenceTest(KSP,PetscInt,PetscReal,KSPConvergedReason*,void*);
-extern PetscErrorCode ConvergenceDestroy(void*);
-extern PetscErrorCode postcheck(SNES,Vec,Vec,Vec,PetscBool*,PetscBool*,void*);
+extern PetscErrorCode FormJacobian(SNES, Vec, Mat, Mat, void *);
+extern PetscErrorCode FormFunction(SNES, Vec, Vec, void *);
+extern PetscErrorCode FormInitialGuess(AppCtx *, Vec);
+extern PetscErrorCode ConvergenceTest(KSP, PetscInt, PetscReal, KSPConvergedReason *, void *);
+extern PetscErrorCode ConvergenceDestroy(void *);
+extern PetscErrorCode postcheck(SNES, Vec, Vec, Vec, PetscBool *, PetscBool *, void *);
 
-int main(int argc,char **argv)
+int main(int argc, char **argv)
 {
-  SNES           snes;                 /* nonlinear solver context */
-  Vec            x,r;                 /* solution, residual vectors */
-  Mat            J;                    /* Jacobian matrix */
-  AppCtx         user;                 /* user-defined application context */
-  PetscErrorCode ierr;
-  PetscInt       i,its,N,hist_its[50];
-  PetscMPIInt    size;
-  PetscReal      bratu_lambda_max = 6.81,bratu_lambda_min = 0.,history[50];
-  MatFDColoring  fdcoloring;
-  PetscBool      matrix_free = PETSC_FALSE,flg,fd_coloring = PETSC_FALSE, use_convergence_test = PETSC_FALSE,pc = PETSC_FALSE;
-  KSP            ksp;
-  PetscInt       *testarray;
+  SNES          snes; /* nonlinear solver context */
+  Vec           x, r; /* solution, residual vectors */
+  Mat           J;    /* Jacobian matrix */
+  AppCtx        user; /* user-defined application context */
+  PetscInt      i, its, N, hist_its[50];
+  PetscMPIInt   size;
+  PetscReal     bratu_lambda_max = 6.81, bratu_lambda_min = 0., history[50];
+  MatFDColoring fdcoloring;
+  PetscBool     matrix_free = PETSC_FALSE, flg, fd_coloring = PETSC_FALSE, use_convergence_test = PETSC_FALSE, pc = PETSC_FALSE;
+  KSP           ksp;
+  PetscInt     *testarray;
 
-  ierr = PetscInitialize(&argc,&argv,(char*)0,help);if (ierr) return ierr;
-  ierr = MPI_Comm_size(PETSC_COMM_WORLD,&size);CHKERRMPI(ierr);
-  if (size != 1) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_WRONG_MPI_SIZE,"This is a uniprocessor example only!");
+  PetscFunctionBeginUser;
+  PetscCall(PetscInitialize(&argc, &argv, (char *)0, help));
+  PetscCallMPI(MPI_Comm_size(PETSC_COMM_WORLD, &size));
+  PetscCheck(size == 1, PETSC_COMM_WORLD, PETSC_ERR_WRONG_MPI_SIZE, "This is a uniprocessor example only!");
 
   /*
      Initialize problem parameters
   */
-  user.mx = 4; user.my = 4; user.param = 6.0;
-  ierr    = PetscOptionsGetInt(NULL,NULL,"-mx",&user.mx,NULL);CHKERRQ(ierr);
-  ierr    = PetscOptionsGetInt(NULL,NULL,"-my",&user.my,NULL);CHKERRQ(ierr);
-  ierr    = PetscOptionsGetReal(NULL,NULL,"-par",&user.param,NULL);CHKERRQ(ierr);
-  ierr    = PetscOptionsGetBool(NULL,NULL,"-pc",&pc,NULL);CHKERRQ(ierr);
-  if (user.param >= bratu_lambda_max || user.param <= bratu_lambda_min) SETERRQ(PETSC_COMM_SELF,PETSC_ERR_ARG_OUTOFRANGE,"Lambda is out of range");
-  N = user.mx*user.my;
-  ierr    = PetscOptionsGetBool(NULL,NULL,"-use_convergence_test",&use_convergence_test,NULL);CHKERRQ(ierr);
+  user.mx    = 4;
+  user.my    = 4;
+  user.param = 6.0;
+  PetscCall(PetscOptionsGetInt(NULL, NULL, "-mx", &user.mx, NULL));
+  PetscCall(PetscOptionsGetInt(NULL, NULL, "-my", &user.my, NULL));
+  PetscCall(PetscOptionsGetReal(NULL, NULL, "-par", &user.param, NULL));
+  PetscCall(PetscOptionsGetBool(NULL, NULL, "-pc", &pc, NULL));
+  PetscCheck(user.param < bratu_lambda_max && user.param > bratu_lambda_min, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Lambda is out of range");
+  N = user.mx * user.my;
+  PetscCall(PetscOptionsGetBool(NULL, NULL, "-use_convergence_test", &use_convergence_test, NULL));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Create nonlinear solver context
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  ierr = SNESCreate(PETSC_COMM_WORLD,&snes);CHKERRQ(ierr);
+  PetscCall(SNESCreate(PETSC_COMM_WORLD, &snes));
 
   if (pc) {
-    ierr = SNESSetType(snes,SNESNEWTONTR);CHKERRQ(ierr);
-    ierr = SNESNewtonTRSetPostCheck(snes, postcheck,NULL);CHKERRQ(ierr);
+    PetscCall(SNESSetType(snes, SNESNEWTONTR));
+    PetscCall(SNESNewtonTRSetPostCheck(snes, postcheck, NULL));
   }
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Create vector data structures; set function evaluation routine
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  ierr = VecCreate(PETSC_COMM_WORLD,&x);CHKERRQ(ierr);
-  ierr = VecSetSizes(x,PETSC_DECIDE,N);CHKERRQ(ierr);
-  ierr = VecSetFromOptions(x);CHKERRQ(ierr);
-  ierr = VecDuplicate(x,&r);CHKERRQ(ierr);
+  PetscCall(VecCreate(PETSC_COMM_WORLD, &x));
+  PetscCall(VecSetSizes(x, PETSC_DECIDE, N));
+  PetscCall(VecSetFromOptions(x));
+  PetscCall(VecDuplicate(x, &r));
 
   /*
      Set function evaluation routine and vector.  Whenever the nonlinear
@@ -122,7 +119,7 @@ int main(int argc,char **argv)
         context that provides application-specific data for the
         function evaluation routine.
   */
-  ierr = SNESSetFunction(snes,r,FormFunction,(void*)&user);CHKERRQ(ierr);
+  PetscCall(SNESSetFunction(snes, r, FormFunction, (void *)&user));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Create matrix data structure; set Jacobian evaluation routine
@@ -133,57 +130,55 @@ int main(int argc,char **argv)
      for the Jacobian.  See the users manual for a discussion of better
      techniques for preallocating matrix memory.
   */
-  ierr = PetscOptionsGetBool(NULL,NULL,"-snes_mf",&matrix_free,NULL);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetBool(NULL, NULL, "-snes_mf", &matrix_free, NULL));
   if (!matrix_free) {
     PetscBool matrix_free_operator = PETSC_FALSE;
-    ierr = PetscOptionsGetBool(NULL,NULL,"-snes_mf_operator",&matrix_free_operator,NULL);CHKERRQ(ierr);
+    PetscCall(PetscOptionsGetBool(NULL, NULL, "-snes_mf_operator", &matrix_free_operator, NULL));
     if (matrix_free_operator) matrix_free = PETSC_FALSE;
   }
-  if (!matrix_free) {
-    ierr = MatCreateSeqAIJ(PETSC_COMM_WORLD,N,N,5,NULL,&J);CHKERRQ(ierr);
-  }
+  if (!matrix_free) PetscCall(MatCreateSeqAIJ(PETSC_COMM_WORLD, N, N, 5, NULL, &J));
 
   /*
      This option will cause the Jacobian to be computed via finite differences
     efficiently using a coloring of the columns of the matrix.
   */
-  ierr = PetscOptionsGetBool(NULL,NULL,"-snes_fd_coloring",&fd_coloring,NULL);CHKERRQ(ierr);
-  if (matrix_free && fd_coloring) SETERRQ(PETSC_COMM_WORLD,PETSC_ERR_ARG_INCOMP,"Use only one of -snes_mf, -snes_fd_coloring options!\nYou can do -snes_mf_operator -snes_fd_coloring");
+  PetscCall(PetscOptionsGetBool(NULL, NULL, "-snes_fd_coloring", &fd_coloring, NULL));
+  PetscCheck(!matrix_free || !fd_coloring, PETSC_COMM_WORLD, PETSC_ERR_ARG_INCOMP, "Use only one of -snes_mf, -snes_fd_coloring options!\nYou can do -snes_mf_operator -snes_fd_coloring");
 
   if (fd_coloring) {
-    ISColoring   iscoloring;
-    MatColoring  mc;
+    ISColoring  iscoloring;
+    MatColoring mc;
 
     /*
       This initializes the nonzero structure of the Jacobian. This is artificial
       because clearly if we had a routine to compute the Jacobian we won't need
       to use finite differences.
     */
-    ierr = FormJacobian(snes,x,J,J,&user);CHKERRQ(ierr);
+    PetscCall(FormJacobian(snes, x, J, J, &user));
 
     /*
        Color the matrix, i.e. determine groups of columns that share no common
       rows. These columns in the Jacobian can all be computed simultaneously.
     */
-    ierr = MatColoringCreate(J,&mc);CHKERRQ(ierr);
-    ierr = MatColoringSetType(mc,MATCOLORINGSL);CHKERRQ(ierr);
-    ierr = MatColoringSetFromOptions(mc);CHKERRQ(ierr);
-    ierr = MatColoringApply(mc,&iscoloring);CHKERRQ(ierr);
-    ierr = MatColoringDestroy(&mc);CHKERRQ(ierr);
+    PetscCall(MatColoringCreate(J, &mc));
+    PetscCall(MatColoringSetType(mc, MATCOLORINGSL));
+    PetscCall(MatColoringSetFromOptions(mc));
+    PetscCall(MatColoringApply(mc, &iscoloring));
+    PetscCall(MatColoringDestroy(&mc));
     /*
        Create the data structure that SNESComputeJacobianDefaultColor() uses
        to compute the actual Jacobians via finite differences.
     */
-    ierr = MatFDColoringCreate(J,iscoloring,&fdcoloring);CHKERRQ(ierr);
-    ierr = MatFDColoringSetFunction(fdcoloring,(PetscErrorCode (*)(void))FormFunction,&user);CHKERRQ(ierr);
-    ierr = MatFDColoringSetFromOptions(fdcoloring);CHKERRQ(ierr);
-    ierr = MatFDColoringSetUp(J,iscoloring,fdcoloring);CHKERRQ(ierr);
+    PetscCall(MatFDColoringCreate(J, iscoloring, &fdcoloring));
+    PetscCall(MatFDColoringSetFunction(fdcoloring, (PetscErrorCode(*)(void))FormFunction, &user));
+    PetscCall(MatFDColoringSetFromOptions(fdcoloring));
+    PetscCall(MatFDColoringSetUp(J, iscoloring, fdcoloring));
     /*
         Tell SNES to use the routine SNESComputeJacobianDefaultColor()
       to compute Jacobians.
     */
-    ierr = SNESSetJacobian(snes,J,J,SNESComputeJacobianDefaultColor,fdcoloring);CHKERRQ(ierr);
-    ierr = ISColoringDestroy(&iscoloring);CHKERRQ(ierr);
+    PetscCall(SNESSetJacobian(snes, J, J, SNESComputeJacobianDefaultColor, fdcoloring));
+    PetscCall(ISColoringDestroy(&iscoloring));
   }
   /*
      Set Jacobian matrix data structure and default Jacobian evaluation
@@ -201,7 +196,7 @@ int main(int argc,char **argv)
                              products within Newton-Krylov method
   */
   else if (!matrix_free) {
-    ierr = SNESSetJacobian(snes,J,J,FormJacobian,(void*)&user);CHKERRQ(ierr);
+    PetscCall(SNESSetJacobian(snes, J, J, FormJacobian, (void *)&user));
   }
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -211,14 +206,14 @@ int main(int argc,char **argv)
   /*
      Set runtime options (e.g., -snes_monitor -snes_rtol <rtol> -ksp_type <type>)
   */
-  ierr = SNESSetFromOptions(snes);CHKERRQ(ierr);
+  PetscCall(SNESSetFromOptions(snes));
 
   /*
      Set array that saves the function norms.  This array is intended
      when the user wants to save the convergence history for later use
      rather than just to view the function norms via -snes_monitor.
   */
-  ierr = SNESSetConvergenceHistory(snes,history,hist_its,50,PETSC_TRUE);CHKERRQ(ierr);
+  PetscCall(SNESSetConvergenceHistory(snes, history, hist_its, 50, PETSC_TRUE));
 
   /*
       Add a user provided convergence test; this is to test that SNESNEWTONTR properly calls the
@@ -226,9 +221,9 @@ int main(int argc,char **argv)
       test that it gets properly freed at the end
   */
   if (use_convergence_test) {
-    ierr = SNESGetKSP(snes,&ksp);CHKERRQ(ierr);
-    ierr = PetscMalloc1(5,&testarray);CHKERRQ(ierr);
-    ierr = KSPSetConvergenceTest(ksp,ConvergenceTest,testarray,ConvergenceDestroy);CHKERRQ(ierr);
+    PetscCall(SNESGetKSP(snes, &ksp));
+    PetscCall(PetscMalloc1(5, &testarray));
+    PetscCall(KSPSetConvergenceTest(ksp, ConvergenceTest, testarray, ConvergenceDestroy));
   }
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -240,20 +235,18 @@ int main(int argc,char **argv)
      to employ an initial guess of zero, the user should explicitly set
      this vector to zero by calling VecSet().
   */
-  ierr = FormInitialGuess(&user,x);CHKERRQ(ierr);
-  ierr = SNESSolve(snes,NULL,x);CHKERRQ(ierr);
-  ierr = SNESGetIterationNumber(snes,&its);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of SNES iterations = %D\n",its);CHKERRQ(ierr);
+  PetscCall(FormInitialGuess(&user, x));
+  PetscCall(SNESSolve(snes, NULL, x));
+  PetscCall(SNESGetIterationNumber(snes, &its));
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Number of SNES iterations = %" PetscInt_FMT "\n", its));
 
   /*
      Print the convergence history.  This is intended just to demonstrate
      use of the data attained via SNESSetConvergenceHistory().
   */
-  ierr = PetscOptionsHasName(NULL,NULL,"-print_history",&flg);CHKERRQ(ierr);
+  PetscCall(PetscOptionsHasName(NULL, NULL, "-print_history", &flg));
   if (flg) {
-    for (i=0; i<its+1; i++) {
-      ierr = PetscPrintf(PETSC_COMM_WORLD,"iteration %D: Linear iterations %D Function norm = %g\n",i,hist_its[i],(double)history[i]);CHKERRQ(ierr);
-    }
+    for (i = 0; i < its + 1; i++) PetscCall(PetscPrintf(PETSC_COMM_WORLD, "iteration %" PetscInt_FMT ": Linear iterations %" PetscInt_FMT " Function norm = %g\n", i, hist_its[i], (double)history[i]));
   }
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -261,19 +254,15 @@ int main(int argc,char **argv)
      are no longer needed.
    - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  if (!matrix_free) {
-    ierr = MatDestroy(&J);CHKERRQ(ierr);
-  }
-  if (fd_coloring) {
-    ierr = MatFDColoringDestroy(&fdcoloring);CHKERRQ(ierr);
-  }
-  ierr = VecDestroy(&x);CHKERRQ(ierr);
-  ierr = VecDestroy(&r);CHKERRQ(ierr);
-  ierr = SNESDestroy(&snes);CHKERRQ(ierr);
-  ierr = PetscFinalize();
-  return ierr;
+  if (!matrix_free) PetscCall(MatDestroy(&J));
+  if (fd_coloring) PetscCall(MatFDColoringDestroy(&fdcoloring));
+  PetscCall(VecDestroy(&x));
+  PetscCall(VecDestroy(&r));
+  PetscCall(SNESDestroy(&snes));
+  PetscCall(PetscFinalize());
+  return 0;
 }
-/* ------------------------------------------------------------------- */
+
 /*
    FormInitialGuess - Forms initial approximation.
 
@@ -284,19 +273,18 @@ int main(int argc,char **argv)
    Output Parameter:
    X - vector
  */
-PetscErrorCode FormInitialGuess(AppCtx *user,Vec X)
+PetscErrorCode FormInitialGuess(AppCtx *user, Vec X)
 {
-  PetscInt       i,j,row,mx,my;
-  PetscErrorCode ierr;
-  PetscReal      lambda,temp1,temp,hx,hy;
-  PetscScalar    *x;
+  PetscInt     i, j, row, mx, my;
+  PetscReal    lambda, temp1, temp, hx, hy;
+  PetscScalar *x;
 
   mx     = user->mx;
   my     = user->my;
   lambda = user->param;
 
-  hx = 1.0 / (PetscReal)(mx-1);
-  hy = 1.0 / (PetscReal)(my-1);
+  hx = 1.0 / (PetscReal)(mx - 1);
+  hy = 1.0 / (PetscReal)(my - 1);
 
   /*
      Get a pointer to vector data.
@@ -305,27 +293,27 @@ PetscErrorCode FormInitialGuess(AppCtx *user,Vec X)
        - You MUST call VecRestoreArray() when you no longer need access to
          the array.
   */
-  ierr  = VecGetArray(X,&x);CHKERRQ(ierr);
-  temp1 = lambda/(lambda + 1.0);
-  for (j=0; j<my; j++) {
-    temp = (PetscReal)(PetscMin(j,my-j-1))*hy;
-    for (i=0; i<mx; i++) {
-      row = i + j*mx;
-      if (i == 0 || j == 0 || i == mx-1 || j == my-1) {
+  PetscCall(VecGetArray(X, &x));
+  temp1 = lambda / (lambda + 1.0);
+  for (j = 0; j < my; j++) {
+    temp = (PetscReal)(PetscMin(j, my - j - 1)) * hy;
+    for (i = 0; i < mx; i++) {
+      row = i + j * mx;
+      if (i == 0 || j == 0 || i == mx - 1 || j == my - 1) {
         x[row] = 0.0;
         continue;
       }
-      x[row] = temp1*PetscSqrtReal(PetscMin((PetscReal)(PetscMin(i,mx-i-1))*hx,temp));
+      x[row] = temp1 * PetscSqrtReal(PetscMin((PetscReal)(PetscMin(i, mx - i - 1)) * hx, temp));
     }
   }
 
   /*
      Restore vector
   */
-  ierr = VecRestoreArray(X,&x);CHKERRQ(ierr);
+  PetscCall(VecRestoreArray(X, &x));
   return 0;
 }
-/* ------------------------------------------------------------------- */
+
 /*
    FormFunction - Evaluates nonlinear function, F(x).
 
@@ -337,37 +325,36 @@ PetscErrorCode FormInitialGuess(AppCtx *user,Vec X)
    Output Parameter:
 .  F - function vector
  */
-PetscErrorCode FormFunction(SNES snes,Vec X,Vec F,void *ptr)
+PetscErrorCode FormFunction(SNES snes, Vec X, Vec F, void *ptr)
 {
-  AppCtx            *user = (AppCtx*)ptr;
-  PetscInt          i,j,row,mx,my;
-  PetscErrorCode    ierr;
-  PetscReal         two = 2.0,one = 1.0,lambda,hx,hy,hxdhy,hydhx;
-  PetscScalar       ut,ub,ul,ur,u,uxx,uyy,sc,*f;
+  AppCtx            *user = (AppCtx *)ptr;
+  PetscInt           i, j, row, mx, my;
+  PetscReal          two = 2.0, one = 1.0, lambda, hx, hy, hxdhy, hydhx;
+  PetscScalar        ut, ub, ul, ur, u, uxx, uyy, sc, *f;
   const PetscScalar *x;
 
   mx     = user->mx;
   my     = user->my;
   lambda = user->param;
-  hx     = one / (PetscReal)(mx-1);
-  hy     = one / (PetscReal)(my-1);
-  sc     = hx*hy;
-  hxdhy  = hx/hy;
-  hydhx  = hy/hx;
+  hx     = one / (PetscReal)(mx - 1);
+  hy     = one / (PetscReal)(my - 1);
+  sc     = hx * hy;
+  hxdhy  = hx / hy;
+  hydhx  = hy / hx;
 
   /*
      Get pointers to vector data
   */
-  ierr = VecGetArrayRead(X,&x);CHKERRQ(ierr);
-  ierr = VecGetArray(F,&f);CHKERRQ(ierr);
+  PetscCall(VecGetArrayRead(X, &x));
+  PetscCall(VecGetArray(F, &f));
 
   /*
      Compute function
   */
-  for (j=0; j<my; j++) {
-    for (i=0; i<mx; i++) {
-      row = i + j*mx;
-      if (i == 0 || j == 0 || i == mx-1 || j == my-1) {
+  for (j = 0; j < my; j++) {
+    for (i = 0; i < mx; i++) {
+      row = i + j * mx;
+      if (i == 0 || j == 0 || i == mx - 1 || j == my - 1) {
         f[row] = x[row];
         continue;
       }
@@ -376,20 +363,20 @@ PetscErrorCode FormFunction(SNES snes,Vec X,Vec F,void *ptr)
       ul     = x[row - 1];
       ut     = x[row + mx];
       ur     = x[row + 1];
-      uxx    = (-ur + two*u - ul)*hydhx;
-      uyy    = (-ut + two*u - ub)*hxdhy;
-      f[row] = uxx + uyy - sc*lambda*PetscExpScalar(u);
+      uxx    = (-ur + two * u - ul) * hydhx;
+      uyy    = (-ut + two * u - ub) * hxdhy;
+      f[row] = uxx + uyy - sc * lambda * PetscExpScalar(u);
     }
   }
 
   /*
      Restore vectors
   */
-  ierr = VecRestoreArrayRead(X,&x);CHKERRQ(ierr);
-  ierr = VecRestoreArray(F,&f);CHKERRQ(ierr);
+  PetscCall(VecRestoreArrayRead(X, &x));
+  PetscCall(VecRestoreArray(F, &f));
   return 0;
 }
-/* ------------------------------------------------------------------- */
+
 /*
    FormJacobian - Evaluates Jacobian matrix.
 
@@ -403,102 +390,101 @@ PetscErrorCode FormFunction(SNES snes,Vec X,Vec F,void *ptr)
 .  B - optionally different preconditioning matrix
 .  flag - flag indicating matrix structure
 */
-PetscErrorCode FormJacobian(SNES snes,Vec X,Mat J,Mat jac,void *ptr)
+PetscErrorCode FormJacobian(SNES snes, Vec X, Mat J, Mat jac, void *ptr)
 {
-  AppCtx            *user = (AppCtx*)ptr;   /* user-defined applicatin context */
-  PetscInt          i,j,row,mx,my,col[5];
-  PetscErrorCode    ierr;
-  PetscScalar       two = 2.0,one = 1.0,lambda,v[5],sc;
+  AppCtx            *user = (AppCtx *)ptr; /* user-defined applicatin context */
+  PetscInt           i, j, row, mx, my, col[5];
+  PetscScalar        two = 2.0, one = 1.0, lambda, v[5], sc;
   const PetscScalar *x;
-  PetscReal         hx,hy,hxdhy,hydhx;
+  PetscReal          hx, hy, hxdhy, hydhx;
 
   mx     = user->mx;
   my     = user->my;
   lambda = user->param;
-  hx     = 1.0 / (PetscReal)(mx-1);
-  hy     = 1.0 / (PetscReal)(my-1);
-  sc     = hx*hy;
-  hxdhy  = hx/hy;
-  hydhx  = hy/hx;
+  hx     = 1.0 / (PetscReal)(mx - 1);
+  hy     = 1.0 / (PetscReal)(my - 1);
+  sc     = hx * hy;
+  hxdhy  = hx / hy;
+  hydhx  = hy / hx;
 
   /*
      Get pointer to vector data
   */
-  ierr = VecGetArrayRead(X,&x);CHKERRQ(ierr);
+  PetscCall(VecGetArrayRead(X, &x));
 
   /*
      Compute entries of the Jacobian
   */
-  for (j=0; j<my; j++) {
-    for (i=0; i<mx; i++) {
-      row = i + j*mx;
-      if (i == 0 || j == 0 || i == mx-1 || j == my-1) {
-        ierr = MatSetValues(jac,1,&row,1,&row,&one,INSERT_VALUES);CHKERRQ(ierr);
+  for (j = 0; j < my; j++) {
+    for (i = 0; i < mx; i++) {
+      row = i + j * mx;
+      if (i == 0 || j == 0 || i == mx - 1 || j == my - 1) {
+        PetscCall(MatSetValues(jac, 1, &row, 1, &row, &one, INSERT_VALUES));
         continue;
       }
-      v[0] = -hxdhy; col[0] = row - mx;
-      v[1] = -hydhx; col[1] = row - 1;
-      v[2] = two*(hydhx + hxdhy) - sc*lambda*PetscExpScalar(x[row]); col[2] = row;
-      v[3] = -hydhx; col[3] = row + 1;
-      v[4] = -hxdhy; col[4] = row + mx;
-      ierr = MatSetValues(jac,1,&row,5,col,v,INSERT_VALUES);CHKERRQ(ierr);
+      v[0]   = -hxdhy;
+      col[0] = row - mx;
+      v[1]   = -hydhx;
+      col[1] = row - 1;
+      v[2]   = two * (hydhx + hxdhy) - sc * lambda * PetscExpScalar(x[row]);
+      col[2] = row;
+      v[3]   = -hydhx;
+      col[3] = row + 1;
+      v[4]   = -hxdhy;
+      col[4] = row + mx;
+      PetscCall(MatSetValues(jac, 1, &row, 5, col, v, INSERT_VALUES));
     }
   }
 
   /*
      Restore vector
   */
-  ierr = VecRestoreArrayRead(X,&x);CHKERRQ(ierr);
+  PetscCall(VecRestoreArrayRead(X, &x));
 
   /*
      Assemble matrix
   */
-  ierr = MatAssemblyBegin(jac,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-  ierr = MatAssemblyEnd(jac,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  PetscCall(MatAssemblyBegin(jac, MAT_FINAL_ASSEMBLY));
+  PetscCall(MatAssemblyEnd(jac, MAT_FINAL_ASSEMBLY));
 
   if (jac != J) {
-    ierr = MatAssemblyBegin(J,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-    ierr = MatAssemblyEnd(J,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+    PetscCall(MatAssemblyBegin(J, MAT_FINAL_ASSEMBLY));
+    PetscCall(MatAssemblyEnd(J, MAT_FINAL_ASSEMBLY));
   }
 
   return 0;
 }
 
-PetscErrorCode ConvergenceTest(KSP ksp,PetscInt it,PetscReal nrm,KSPConvergedReason *reason,void *ctx)
+PetscErrorCode ConvergenceTest(KSP ksp, PetscInt it, PetscReal nrm, KSPConvergedReason *reason, void *ctx)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
   *reason = KSP_CONVERGED_ITERATING;
   if (it > 1) {
     *reason = KSP_CONVERGED_ITS;
-    ierr = PetscInfo(NULL,"User provided convergence test returning after 2 iterations\n");CHKERRQ(ierr);
+    PetscCall(PetscInfo(NULL, "User provided convergence test returning after 2 iterations\n"));
   }
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode ConvergenceDestroy(void* ctx)
+PetscErrorCode ConvergenceDestroy(void *ctx)
 {
-  PetscErrorCode ierr;
-
   PetscFunctionBegin;
-  ierr = PetscInfo(NULL,"User provided convergence destroy called\n");CHKERRQ(ierr);
-  ierr = PetscFree(ctx);CHKERRQ(ierr);
+  PetscCall(PetscInfo(NULL, "User provided convergence destroy called\n"));
+  PetscCall(PetscFree(ctx));
   PetscFunctionReturn(0);
 }
 
-PetscErrorCode postcheck(SNES snes,Vec x,Vec y,Vec w,PetscBool *changed_y,PetscBool *changed_w,void *ctx)
+PetscErrorCode postcheck(SNES snes, Vec x, Vec y, Vec w, PetscBool *changed_y, PetscBool *changed_w, void *ctx)
 {
-  PetscErrorCode ierr;
-  PetscReal      norm;
-  Vec            tmp;
+  PetscReal norm;
+  Vec       tmp;
 
   PetscFunctionBegin;
-  ierr = VecDuplicate(x,&tmp);CHKERRQ(ierr);
-  ierr = VecWAXPY(tmp,-1.0,x,w);CHKERRQ(ierr);
-  ierr = VecNorm(tmp,NORM_2,&norm);CHKERRQ(ierr);
-  ierr = VecDestroy(&tmp);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Norm of search step %g\n",(double)norm);CHKERRQ(ierr);
+  PetscCall(VecDuplicate(x, &tmp));
+  PetscCall(VecWAXPY(tmp, -1.0, x, w));
+  PetscCall(VecNorm(tmp, NORM_2, &norm));
+  PetscCall(VecDestroy(&tmp));
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Norm of search step %g\n", (double)norm));
   PetscFunctionReturn(0);
 }
 
@@ -535,4 +521,3 @@ PetscErrorCode postcheck(SNES snes,Vec x,Vec y,Vec w,PetscBool *changed_y,PetscB
       args: -pc -par 6.807 -snes_monitor -snes_converged_reason
 
 TEST*/
-
