@@ -7,14 +7,6 @@ The command line options include:\n\
   -check_tol <tol>: set tolerance for iterate checking\n\
   -user_precond : activate a (trivial) user-defined preconditioner\n\n";
 
-/*T
-   Concepts: SNES^basic parallel example
-   Concepts: SNES^setting a user-defined monitoring routine
-   Processors: n
-T*/
-
-
-
 /*
    Include "petscdm.h" so that we can use data management objects (DMs)
    Include "petscdmda.h" so that we can use distributed arrays (DMDAs).
@@ -37,25 +29,25 @@ T*/
 /*
    User-defined routines.
 */
-PetscErrorCode FormJacobian(SNES,Vec,Mat,Mat,void*);
-PetscErrorCode FormFunction(SNES,Vec,Vec,void*);
+PetscErrorCode FormJacobian(SNES, Vec, Mat, Mat, void *);
+PetscErrorCode FormFunction(SNES, Vec, Vec, void *);
 PetscErrorCode FormInitialGuess(Vec);
-PetscErrorCode Monitor(SNES,PetscInt,PetscReal,void*);
-PetscErrorCode PreCheck(SNESLineSearch,Vec,Vec,PetscBool*,void*);
-PetscErrorCode PostCheck(SNESLineSearch,Vec,Vec,Vec,PetscBool*,PetscBool*,void*);
-PetscErrorCode PostSetSubKSP(SNESLineSearch,Vec,Vec,Vec,PetscBool*,PetscBool*,void*);
-PetscErrorCode MatrixFreePreconditioner(PC,Vec,Vec);
+PetscErrorCode Monitor(SNES, PetscInt, PetscReal, void *);
+PetscErrorCode PreCheck(SNESLineSearch, Vec, Vec, PetscBool *, void *);
+PetscErrorCode PostCheck(SNESLineSearch, Vec, Vec, Vec, PetscBool *, PetscBool *, void *);
+PetscErrorCode PostSetSubKSP(SNESLineSearch, Vec, Vec, Vec, PetscBool *, PetscBool *, void *);
+PetscErrorCode MatrixFreePreconditioner(PC, Vec, Vec);
 
 /*
    User-defined application context
 */
 typedef struct {
-  DM          da;      /* distributed array */
-  Vec         F;       /* right-hand-side of PDE */
-  PetscMPIInt rank;    /* rank of processor */
-  PetscMPIInt size;    /* size of communicator */
-  PetscReal   h;       /* mesh spacing */
-  PetscBool   sjerr;   /* if or not to test jacobian domain error */
+  DM          da;    /* distributed array */
+  Vec         F;     /* right-hand-side of PDE */
+  PetscMPIInt rank;  /* rank of processor */
+  PetscMPIInt size;  /* size of communicator */
+  PetscReal   h;     /* mesh spacing */
+  PetscBool   sjerr; /* if or not to test jacobian domain error */
 } ApplicationCtx;
 
 /*
@@ -70,8 +62,8 @@ typedef struct {
    determined by line search methods
 */
 typedef struct {
-  Vec            last_step;  /* previous iterate */
-  PetscReal      tolerance;  /* tolerance for changes between successive iterates */
+  Vec             last_step; /* previous iterate */
+  PetscReal       tolerance; /* tolerance for changes between successive iterates */
   ApplicationCtx *user;
 } StepCheckCtx;
 
@@ -79,38 +71,37 @@ typedef struct {
   PetscInt its0; /* num of prevous outer KSP iterations */
 } SetSubKSPCtx;
 
-int main(int argc,char **argv)
+int main(int argc, char **argv)
 {
-  SNES           snes;                 /* SNES context */
-  SNESLineSearch linesearch;           /* SNESLineSearch context */
-  Mat            J;                    /* Jacobian matrix */
-  ApplicationCtx ctx;                  /* user-defined context */
-  Vec            x,r,U,F;              /* vectors */
-  MonitorCtx     monP;                 /* monitoring context */
-  StepCheckCtx   checkP;               /* step-checking context */
+  SNES           snes;       /* SNES context */
+  SNESLineSearch linesearch; /* SNESLineSearch context */
+  Mat            J;          /* Jacobian matrix */
+  ApplicationCtx ctx;        /* user-defined context */
+  Vec            x, r, U, F; /* vectors */
+  MonitorCtx     monP;       /* monitoring context */
+  StepCheckCtx   checkP;     /* step-checking context */
   SetSubKSPCtx   checkP1;
-  PetscBool      pre_check,post_check,post_setsubksp; /* flag indicating whether we're checking candidate iterates */
-  PetscScalar    xp,*FF,*UU,none = -1.0;
-  PetscErrorCode ierr;
-  PetscInt       its,N = 5,i,maxit,maxf,xs,xm;
-  PetscReal      abstol,rtol,stol,norm;
-  PetscBool      flg,viewinitial = PETSC_FALSE;
+  PetscBool      pre_check, post_check, post_setsubksp; /* flag indicating whether we're checking candidate iterates */
+  PetscScalar    xp, *FF, *UU, none = -1.0;
+  PetscInt       its, N = 5, i, maxit, maxf, xs, xm;
+  PetscReal      abstol, rtol, stol, norm;
+  PetscBool      flg, viewinitial = PETSC_FALSE;
 
-
-  ierr = PetscInitialize(&argc,&argv,(char*)0,help);if (ierr) return ierr;
-  ierr  = MPI_Comm_rank(PETSC_COMM_WORLD,&ctx.rank);CHKERRMPI(ierr);
-  ierr  = MPI_Comm_size(PETSC_COMM_WORLD,&ctx.size);CHKERRMPI(ierr);
-  ierr  = PetscOptionsGetInt(NULL,NULL,"-n",&N,NULL);CHKERRQ(ierr);
-  ctx.h = 1.0/(N-1);
+  PetscFunctionBeginUser;
+  PetscCall(PetscInitialize(&argc, &argv, (char *)0, help));
+  PetscCallMPI(MPI_Comm_rank(PETSC_COMM_WORLD, &ctx.rank));
+  PetscCallMPI(MPI_Comm_size(PETSC_COMM_WORLD, &ctx.size));
+  PetscCall(PetscOptionsGetInt(NULL, NULL, "-n", &N, NULL));
+  ctx.h     = 1.0 / (N - 1);
   ctx.sjerr = PETSC_FALSE;
-  ierr  = PetscOptionsGetBool(NULL,NULL,"-test_jacobian_domain_error",&ctx.sjerr,NULL);CHKERRQ(ierr);
-  ierr  = PetscOptionsGetBool(NULL,NULL,"-view_initial",&viewinitial,NULL);CHKERRQ(ierr);
+  PetscCall(PetscOptionsGetBool(NULL, NULL, "-test_jacobian_domain_error", &ctx.sjerr, NULL));
+  PetscCall(PetscOptionsGetBool(NULL, NULL, "-view_initial", &viewinitial, NULL));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Create nonlinear solver context
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  ierr = SNESCreate(PETSC_COMM_WORLD,&snes);CHKERRQ(ierr);
+  PetscCall(SNESCreate(PETSC_COMM_WORLD, &snes));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Create vector data structures; set function evaluation routine
@@ -119,18 +110,19 @@ int main(int argc,char **argv)
   /*
      Create distributed array (DMDA) to manage parallel grid and vectors
   */
-  ierr = DMDACreate1d(PETSC_COMM_WORLD,DM_BOUNDARY_NONE,N,1,1,NULL,&ctx.da);CHKERRQ(ierr);
-  ierr = DMSetFromOptions(ctx.da);CHKERRQ(ierr);
-  ierr = DMSetUp(ctx.da);CHKERRQ(ierr);
+  PetscCall(DMDACreate1d(PETSC_COMM_WORLD, DM_BOUNDARY_NONE, N, 1, 1, NULL, &ctx.da));
+  PetscCall(DMSetFromOptions(ctx.da));
+  PetscCall(DMSetUp(ctx.da));
 
   /*
      Extract global and local vectors from DMDA; then duplicate for remaining
      vectors that are the same types
   */
-  ierr = DMCreateGlobalVector(ctx.da,&x);CHKERRQ(ierr);
-  ierr = VecDuplicate(x,&r);CHKERRQ(ierr);
-  ierr = VecDuplicate(x,&F);CHKERRQ(ierr); ctx.F = F;
-  ierr = VecDuplicate(x,&U);CHKERRQ(ierr);
+  PetscCall(DMCreateGlobalVector(ctx.da, &x));
+  PetscCall(VecDuplicate(x, &r));
+  PetscCall(VecDuplicate(x, &F));
+  ctx.F = F;
+  PetscCall(VecDuplicate(x, &U));
 
   /*
      Set function evaluation routine and vector.  Whenever the nonlinear
@@ -140,17 +132,17 @@ int main(int argc,char **argv)
         context that provides application-specific data for the
         function evaluation routine.
   */
-  ierr = SNESSetFunction(snes,r,FormFunction,&ctx);CHKERRQ(ierr);
+  PetscCall(SNESSetFunction(snes, r, FormFunction, &ctx));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Create matrix data structure; set Jacobian evaluation routine
      - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */
 
-  ierr = MatCreate(PETSC_COMM_WORLD,&J);CHKERRQ(ierr);
-  ierr = MatSetSizes(J,PETSC_DECIDE,PETSC_DECIDE,N,N);CHKERRQ(ierr);
-  ierr = MatSetFromOptions(J);CHKERRQ(ierr);
-  ierr = MatSeqAIJSetPreallocation(J,3,NULL);CHKERRQ(ierr);
-  ierr = MatMPIAIJSetPreallocation(J,3,NULL,3,NULL);CHKERRQ(ierr);
+  PetscCall(MatCreate(PETSC_COMM_WORLD, &J));
+  PetscCall(MatSetSizes(J, PETSC_DECIDE, PETSC_DECIDE, N, N));
+  PetscCall(MatSetFromOptions(J));
+  PetscCall(MatSeqAIJSetPreallocation(J, 3, NULL));
+  PetscCall(MatMPIAIJSetPreallocation(J, 3, NULL, 3, NULL));
 
   /*
      Set Jacobian matrix data structure and default Jacobian evaluation
@@ -160,19 +152,19 @@ int main(int argc,char **argv)
         context that provides application-specific data for the
         Jacobian evaluation routine.
   */
-  ierr = SNESSetJacobian(snes,J,J,FormJacobian,&ctx);CHKERRQ(ierr);
+  PetscCall(SNESSetJacobian(snes, J, J, FormJacobian, &ctx));
 
   /*
      Optionally allow user-provided preconditioner
    */
-  ierr = PetscOptionsHasName(NULL,NULL,"-user_precond",&flg);CHKERRQ(ierr);
+  PetscCall(PetscOptionsHasName(NULL, NULL, "-user_precond", &flg));
   if (flg) {
     KSP ksp;
     PC  pc;
-    ierr = SNESGetKSP(snes,&ksp);CHKERRQ(ierr);
-    ierr = KSPGetPC(ksp,&pc);CHKERRQ(ierr);
-    ierr = PCSetType(pc,PCSHELL);CHKERRQ(ierr);
-    ierr = PCShellSetApply(pc,MatrixFreePreconditioner);CHKERRQ(ierr);
+    PetscCall(SNESGetKSP(snes, &ksp));
+    PetscCall(KSPGetPC(ksp, &pc));
+    PetscCall(PCSetType(pc, PCSHELL));
+    PetscCall(PCShellSetApply(pc, MatrixFreePreconditioner));
   }
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -182,49 +174,49 @@ int main(int argc,char **argv)
   /*
      Set an optional user-defined monitoring routine
   */
-  ierr = PetscViewerDrawOpen(PETSC_COMM_WORLD,0,0,0,0,400,400,&monP.viewer);CHKERRQ(ierr);
-  ierr = SNESMonitorSet(snes,Monitor,&monP,0);CHKERRQ(ierr);
+  PetscCall(PetscViewerDrawOpen(PETSC_COMM_WORLD, 0, 0, 0, 0, 400, 400, &monP.viewer));
+  PetscCall(SNESMonitorSet(snes, Monitor, &monP, 0));
 
   /*
      Set names for some vectors to facilitate monitoring (optional)
   */
-  ierr = PetscObjectSetName((PetscObject)x,"Approximate Solution");CHKERRQ(ierr);
-  ierr = PetscObjectSetName((PetscObject)U,"Exact Solution");CHKERRQ(ierr);
+  PetscCall(PetscObjectSetName((PetscObject)x, "Approximate Solution"));
+  PetscCall(PetscObjectSetName((PetscObject)U, "Exact Solution"));
 
   /*
      Set SNES/KSP/KSP/PC runtime options, e.g.,
          -snes_view -snes_monitor -ksp_type <ksp> -pc_type <pc>
   */
-  ierr = SNESSetFromOptions(snes);CHKERRQ(ierr);
+  PetscCall(SNESSetFromOptions(snes));
 
   /*
      Set an optional user-defined routine to check the validity of candidate
      iterates that are determined by line search methods
   */
-  ierr = SNESGetLineSearch(snes, &linesearch);CHKERRQ(ierr);
-  ierr = PetscOptionsHasName(NULL,NULL,"-post_check_iterates",&post_check);CHKERRQ(ierr);
+  PetscCall(SNESGetLineSearch(snes, &linesearch));
+  PetscCall(PetscOptionsHasName(NULL, NULL, "-post_check_iterates", &post_check));
 
   if (post_check) {
-    ierr = PetscPrintf(PETSC_COMM_WORLD,"Activating post step checking routine\n");CHKERRQ(ierr);
-    ierr = SNESLineSearchSetPostCheck(linesearch,PostCheck,&checkP);CHKERRQ(ierr);
-    ierr = VecDuplicate(x,&(checkP.last_step));CHKERRQ(ierr);
+    PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Activating post step checking routine\n"));
+    PetscCall(SNESLineSearchSetPostCheck(linesearch, PostCheck, &checkP));
+    PetscCall(VecDuplicate(x, &(checkP.last_step)));
 
     checkP.tolerance = 1.0;
     checkP.user      = &ctx;
 
-    ierr = PetscOptionsGetReal(NULL,NULL,"-check_tol",&checkP.tolerance,NULL);CHKERRQ(ierr);
+    PetscCall(PetscOptionsGetReal(NULL, NULL, "-check_tol", &checkP.tolerance, NULL));
   }
 
-  ierr = PetscOptionsHasName(NULL,NULL,"-post_setsubksp",&post_setsubksp);CHKERRQ(ierr);
+  PetscCall(PetscOptionsHasName(NULL, NULL, "-post_setsubksp", &post_setsubksp));
   if (post_setsubksp) {
-    ierr = PetscPrintf(PETSC_COMM_WORLD,"Activating post setsubksp\n");CHKERRQ(ierr);
-    ierr = SNESLineSearchSetPostCheck(linesearch,PostSetSubKSP,&checkP1);CHKERRQ(ierr);
+    PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Activating post setsubksp\n"));
+    PetscCall(SNESLineSearchSetPostCheck(linesearch, PostSetSubKSP, &checkP1));
   }
 
-  ierr = PetscOptionsHasName(NULL,NULL,"-pre_check_iterates",&pre_check);CHKERRQ(ierr);
+  PetscCall(PetscOptionsHasName(NULL, NULL, "-pre_check_iterates", &pre_check));
   if (pre_check) {
-    ierr = PetscPrintf(PETSC_COMM_WORLD,"Activating pre step checking routine\n");CHKERRQ(ierr);
-    ierr = SNESLineSearchSetPreCheck(linesearch,PreCheck,&checkP);CHKERRQ(ierr);
+    PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Activating pre step checking routine\n"));
+    PetscCall(SNESLineSearchSetPreCheck(linesearch, PreCheck, &checkP));
   }
 
   /*
@@ -232,8 +224,8 @@ int main(int argc,char **argv)
      to demonstrate this routine; this information is also printed with
      the option -snes_view
   */
-  ierr = SNESGetTolerances(snes,&abstol,&rtol,&stol,&maxit,&maxf);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"atol=%g, rtol=%g, stol=%g, maxit=%D, maxf=%D\n",(double)abstol,(double)rtol,(double)stol,maxit,maxf);CHKERRQ(ierr);
+  PetscCall(SNESGetTolerances(snes, &abstol, &rtol, &stol, &maxit, &maxf));
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD, "atol=%g, rtol=%g, stol=%g, maxit=%" PetscInt_FMT ", maxf=%" PetscInt_FMT "\n", (double)abstol, (double)rtol, (double)stol, maxit, maxf));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Initialize application:
@@ -244,32 +236,32 @@ int main(int argc,char **argv)
      Get local grid boundaries (for 1-dimensional DMDA):
        xs, xm - starting grid index, width of local grid (no ghost points)
   */
-  ierr = DMDAGetCorners(ctx.da,&xs,NULL,NULL,&xm,NULL,NULL);CHKERRQ(ierr);
+  PetscCall(DMDAGetCorners(ctx.da, &xs, NULL, NULL, &xm, NULL, NULL));
 
   /*
      Get pointers to vector data
   */
-  ierr = DMDAVecGetArray(ctx.da,F,&FF);CHKERRQ(ierr);
-  ierr = DMDAVecGetArray(ctx.da,U,&UU);CHKERRQ(ierr);
+  PetscCall(DMDAVecGetArray(ctx.da, F, &FF));
+  PetscCall(DMDAVecGetArray(ctx.da, U, &UU));
 
   /*
      Compute local vector entries
   */
-  xp = ctx.h*xs;
-  for (i=xs; i<xs+xm; i++) {
-    FF[i] = 6.0*xp + PetscPowScalar(xp+1.e-12,6.0); /* +1.e-12 is to prevent 0^6 */
-    UU[i] = xp*xp*xp;
-    xp   += ctx.h;
+  xp = ctx.h * xs;
+  for (i = xs; i < xs + xm; i++) {
+    FF[i] = 6.0 * xp + PetscPowScalar(xp + 1.e-12, 6.0); /* +1.e-12 is to prevent 0^6 */
+    UU[i] = xp * xp * xp;
+    xp += ctx.h;
   }
 
   /*
      Restore vectors
   */
-  ierr = DMDAVecRestoreArray(ctx.da,F,&FF);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreArray(ctx.da,U,&UU);CHKERRQ(ierr);
+  PetscCall(DMDAVecRestoreArray(ctx.da, F, &FF));
+  PetscCall(DMDAVecRestoreArray(ctx.da, U, &UU));
   if (viewinitial) {
-    ierr = VecView(U,0);CHKERRQ(ierr);
-    ierr = VecView(F,0);CHKERRQ(ierr);
+    PetscCall(VecView(U, 0));
+    PetscCall(VecView(F, 0));
   }
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
@@ -282,10 +274,10 @@ int main(int argc,char **argv)
      to employ an initial guess of zero, the user should explicitly set
      this vector to zero by calling VecSet().
   */
-  ierr = FormInitialGuess(x);CHKERRQ(ierr);
-  ierr = SNESSolve(snes,NULL,x);CHKERRQ(ierr);
-  ierr = SNESGetIterationNumber(snes,&its);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Number of SNES iterations = %D\n",its);CHKERRQ(ierr);
+  PetscCall(FormInitialGuess(x));
+  PetscCall(SNESSolve(snes, NULL, x));
+  PetscCall(SNESGetIterationNumber(snes, &its));
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Number of SNES iterations = %" PetscInt_FMT "\n", its));
 
   /* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
      Check solution and clean up
@@ -294,30 +286,30 @@ int main(int argc,char **argv)
   /*
      Check the error
   */
-  ierr = VecAXPY(x,none,U);CHKERRQ(ierr);
-  ierr = VecNorm(x,NORM_2,&norm);CHKERRQ(ierr);
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"Norm of error %g Iterations %D\n",(double)norm,its);CHKERRQ(ierr);
+  PetscCall(VecAXPY(x, none, U));
+  PetscCall(VecNorm(x, NORM_2, &norm));
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Norm of error %g Iterations %" PetscInt_FMT "\n", (double)norm, its));
   if (ctx.sjerr) {
-    SNESType       snestype;
-    ierr = SNESGetType(snes,&snestype);CHKERRQ(ierr);
-    ierr = PetscPrintf(PETSC_COMM_WORLD,"SNES Type %s\n",snestype);CHKERRQ(ierr);
+    SNESType snestype;
+    PetscCall(SNESGetType(snes, &snestype));
+    PetscCall(PetscPrintf(PETSC_COMM_WORLD, "SNES Type %s\n", snestype));
   }
 
   /*
      Free work space.  All PETSc objects should be destroyed when they
      are no longer needed.
   */
-  ierr = PetscViewerDestroy(&monP.viewer);CHKERRQ(ierr);
-  if (post_check) {ierr = VecDestroy(&checkP.last_step);CHKERRQ(ierr);}
-  ierr = VecDestroy(&x);CHKERRQ(ierr);
-  ierr = VecDestroy(&r);CHKERRQ(ierr);
-  ierr = VecDestroy(&U);CHKERRQ(ierr);
-  ierr = VecDestroy(&F);CHKERRQ(ierr);
-  ierr = MatDestroy(&J);CHKERRQ(ierr);
-  ierr = SNESDestroy(&snes);CHKERRQ(ierr);
-  ierr = DMDestroy(&ctx.da);CHKERRQ(ierr);
-  ierr = PetscFinalize();
-  return ierr;
+  PetscCall(PetscViewerDestroy(&monP.viewer));
+  if (post_check) PetscCall(VecDestroy(&checkP.last_step));
+  PetscCall(VecDestroy(&x));
+  PetscCall(VecDestroy(&r));
+  PetscCall(VecDestroy(&U));
+  PetscCall(VecDestroy(&F));
+  PetscCall(MatDestroy(&J));
+  PetscCall(SNESDestroy(&snes));
+  PetscCall(DMDestroy(&ctx.da));
+  PetscCall(PetscFinalize());
+  return 0;
 }
 
 /* ------------------------------------------------------------------- */
@@ -329,11 +321,10 @@ int main(int argc,char **argv)
 */
 PetscErrorCode FormInitialGuess(Vec x)
 {
-  PetscErrorCode ierr;
-  PetscScalar    pfive = .50;
+  PetscScalar pfive = .50;
 
   PetscFunctionBeginUser;
-  ierr = VecSet(x,pfive);CHKERRQ(ierr);
+  PetscCall(VecSet(x, pfive));
   PetscFunctionReturn(0);
 }
 
@@ -353,25 +344,25 @@ PetscErrorCode FormInitialGuess(Vec x)
    The user-defined context can contain any application-specific
    data needed for the function evaluation.
 */
-PetscErrorCode FormFunction(SNES snes,Vec x,Vec f,void *ctx)
+PetscErrorCode FormFunction(SNES snes, Vec x, Vec f, void *ctx)
 {
-  ApplicationCtx *user = (ApplicationCtx*) ctx;
-  DM             da    = user->da;
-  PetscScalar    *xx,*ff,*FF,d;
-  PetscErrorCode ierr;
-  PetscInt       i,M,xs,xm;
-  Vec            xlocal;
+  ApplicationCtx    *user = (ApplicationCtx *)ctx;
+  DM                 da   = user->da;
+  PetscScalar       *ff, d;
+  const PetscScalar *xx, *FF;
+  PetscInt           i, M, xs, xm;
+  Vec                xlocal;
 
   PetscFunctionBeginUser;
-  ierr = DMGetLocalVector(da,&xlocal);CHKERRQ(ierr);
+  PetscCall(DMGetLocalVector(da, &xlocal));
   /*
      Scatter ghost points to local vector, using the 2-step process
         DMGlobalToLocalBegin(), DMGlobalToLocalEnd().
      By placing code between these two statements, computations can
      be done while messages are in transition.
   */
-  ierr = DMGlobalToLocalBegin(da,x,INSERT_VALUES,xlocal);CHKERRQ(ierr);
-  ierr = DMGlobalToLocalEnd(da,x,INSERT_VALUES,xlocal);CHKERRQ(ierr);
+  PetscCall(DMGlobalToLocalBegin(da, x, INSERT_VALUES, xlocal));
+  PetscCall(DMGlobalToLocalEnd(da, x, INSERT_VALUES, xlocal));
 
   /*
      Get pointers to vector data.
@@ -379,16 +370,16 @@ PetscErrorCode FormFunction(SNES snes,Vec x,Vec f,void *ctx)
          NOT include ghost points.
        - Using DMDAVecGetArray() allows accessing the values using global ordering
   */
-  ierr = DMDAVecGetArray(da,xlocal,&xx);CHKERRQ(ierr);
-  ierr = DMDAVecGetArray(da,f,&ff);CHKERRQ(ierr);
-  ierr = DMDAVecGetArray(da,user->F,&FF);CHKERRQ(ierr);
+  PetscCall(DMDAVecGetArrayRead(da, xlocal, (void *)&xx));
+  PetscCall(DMDAVecGetArray(da, f, &ff));
+  PetscCall(DMDAVecGetArrayRead(da, user->F, (void *)&FF));
 
   /*
      Get local grid boundaries (for 1-dimensional DMDA):
        xs, xm  - starting grid index, width of local grid (no ghost points)
   */
-  ierr = DMDAGetCorners(da,&xs,NULL,NULL,&xm,NULL,NULL);CHKERRQ(ierr);
-  ierr = DMDAGetInfo(da,NULL,&M,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL);CHKERRQ(ierr);
+  PetscCall(DMDAGetCorners(da, &xs, NULL, NULL, &xm, NULL, NULL));
+  PetscCall(DMDAGetInfo(da, NULL, &M, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL));
 
   /*
      Set function values for boundary points; define local interior grid point range:
@@ -397,26 +388,27 @@ PetscErrorCode FormFunction(SNES snes,Vec x,Vec f,void *ctx)
   */
   if (xs == 0) { /* left boundary */
     ff[0] = xx[0];
-    xs++;xm--;
+    xs++;
+    xm--;
   }
-  if (xs+xm == M) {  /* right boundary */
-    ff[xs+xm-1] = xx[xs+xm-1] - 1.0;
+  if (xs + xm == M) { /* right boundary */
+    ff[xs + xm - 1] = xx[xs + xm - 1] - 1.0;
     xm--;
   }
 
   /*
      Compute function over locally owned part of the grid (interior points only)
   */
-  d = 1.0/(user->h*user->h);
-  for (i=xs; i<xs+xm; i++) ff[i] = d*(xx[i-1] - 2.0*xx[i] + xx[i+1]) + xx[i]*xx[i] - FF[i];
+  d = 1.0 / (user->h * user->h);
+  for (i = xs; i < xs + xm; i++) ff[i] = d * (xx[i - 1] - 2.0 * xx[i] + xx[i + 1]) + xx[i] * xx[i] - FF[i];
 
   /*
      Restore vectors
   */
-  ierr = DMDAVecRestoreArray(da,xlocal,&xx);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreArray(da,f,&ff);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreArray(da,user->F,&FF);CHKERRQ(ierr);
-  ierr = DMRestoreLocalVector(da,&xlocal);CHKERRQ(ierr);
+  PetscCall(DMDAVecRestoreArrayRead(da, xlocal, (void *)&xx));
+  PetscCall(DMDAVecRestoreArray(da, f, &ff));
+  PetscCall(DMDAVecRestoreArrayRead(da, user->F, (void *)&FF));
+  PetscCall(DMRestoreLocalVector(da, &xlocal));
   PetscFunctionReturn(0);
 }
 
@@ -434,45 +426,46 @@ PetscErrorCode FormFunction(SNES snes,Vec x,Vec f,void *ctx)
 .  B - optionally different preconditioning matrix
 .  flag - flag indicating matrix structure
 */
-PetscErrorCode FormJacobian(SNES snes,Vec x,Mat jac,Mat B,void *ctx)
+PetscErrorCode FormJacobian(SNES snes, Vec x, Mat jac, Mat B, void *ctx)
 {
-  ApplicationCtx *user = (ApplicationCtx*) ctx;
-  PetscScalar    *xx,d,A[3];
-  PetscErrorCode ierr;
-  PetscInt       i,j[3],M,xs,xm;
-  DM             da = user->da;
+  ApplicationCtx *user = (ApplicationCtx *)ctx;
+  PetscScalar    *xx, d, A[3];
+  PetscInt        i, j[3], M, xs, xm;
+  DM              da = user->da;
 
   PetscFunctionBeginUser;
   if (user->sjerr) {
-    ierr = SNESSetJacobianDomainError(snes);CHKERRQ(ierr);
+    PetscCall(SNESSetJacobianDomainError(snes));
     PetscFunctionReturn(0);
   }
   /*
      Get pointer to vector data
   */
-  ierr = DMDAVecGetArrayRead(da,x,&xx);CHKERRQ(ierr);
-  ierr = DMDAGetCorners(da,&xs,NULL,NULL,&xm,NULL,NULL);CHKERRQ(ierr);
+  PetscCall(DMDAVecGetArrayRead(da, x, &xx));
+  PetscCall(DMDAGetCorners(da, &xs, NULL, NULL, &xm, NULL, NULL));
 
   /*
     Get range of locally owned matrix
   */
-  ierr = DMDAGetInfo(da,NULL,&M,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL);CHKERRQ(ierr);
+  PetscCall(DMDAGetInfo(da, NULL, &M, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL));
 
   /*
      Determine starting and ending local indices for interior grid points.
      Set Jacobian entries for boundary points.
   */
 
-  if (xs == 0) {  /* left boundary */
-    i = 0; A[0] = 1.0;
-
-    ierr = MatSetValues(jac,1,&i,1,&i,A,INSERT_VALUES);CHKERRQ(ierr);
-    xs++;xm--;
-  }
-  if (xs+xm == M) { /* right boundary */
-    i    = M-1;
+  if (xs == 0) { /* left boundary */
+    i    = 0;
     A[0] = 1.0;
-    ierr = MatSetValues(jac,1,&i,1,&i,A,INSERT_VALUES);CHKERRQ(ierr);
+
+    PetscCall(MatSetValues(jac, 1, &i, 1, &i, A, INSERT_VALUES));
+    xs++;
+    xm--;
+  }
+  if (xs + xm == M) { /* right boundary */
+    i    = M - 1;
+    A[0] = 1.0;
+    PetscCall(MatSetValues(jac, 1, &i, 1, &i, A, INSERT_VALUES));
     xm--;
   }
 
@@ -481,11 +474,14 @@ PetscErrorCode FormJacobian(SNES snes,Vec x,Mat jac,Mat B,void *ctx)
       - Note that in this case we set all elements for a particular
         row at once.
   */
-  d = 1.0/(user->h*user->h);
-  for (i=xs; i<xs+xm; i++) {
-    j[0] = i - 1; j[1] = i; j[2] = i + 1;
-    A[0] = A[2] = d; A[1] = -2.0*d + 2.0*xx[i];
-    ierr = MatSetValues(jac,1,&i,3,j,A,INSERT_VALUES);CHKERRQ(ierr);
+  d = 1.0 / (user->h * user->h);
+  for (i = xs; i < xs + xm; i++) {
+    j[0] = i - 1;
+    j[1] = i;
+    j[2] = i + 1;
+    A[0] = A[2] = d;
+    A[1]        = -2.0 * d + 2.0 * xx[i];
+    PetscCall(MatSetValues(jac, 1, &i, 3, j, A, INSERT_VALUES));
   }
 
   /*
@@ -497,9 +493,9 @@ PetscErrorCode FormJacobian(SNES snes,Vec x,Mat jac,Mat B,void *ctx)
      Also, restore vector.
   */
 
-  ierr = MatAssemblyBegin(jac,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
-  ierr = DMDAVecRestoreArrayRead(da,x,&xx);CHKERRQ(ierr);
-  ierr = MatAssemblyEnd(jac,MAT_FINAL_ASSEMBLY);CHKERRQ(ierr);
+  PetscCall(MatAssemblyBegin(jac, MAT_FINAL_ASSEMBLY));
+  PetscCall(DMDAVecRestoreArrayRead(da, x, &xx));
+  PetscCall(MatAssemblyEnd(jac, MAT_FINAL_ASSEMBLY));
 
   PetscFunctionReturn(0);
 }
@@ -520,16 +516,15 @@ PetscErrorCode FormJacobian(SNES snes,Vec x,Mat jac,Mat B,void *ctx)
    See the manpage for PetscViewerDrawOpen() for useful runtime options,
    such as -nox to deactivate all x-window output.
  */
-PetscErrorCode Monitor(SNES snes,PetscInt its,PetscReal fnorm,void *ctx)
+PetscErrorCode Monitor(SNES snes, PetscInt its, PetscReal fnorm, void *ctx)
 {
-  PetscErrorCode ierr;
-  MonitorCtx     *monP = (MonitorCtx*) ctx;
-  Vec            x;
+  MonitorCtx *monP = (MonitorCtx *)ctx;
+  Vec         x;
 
   PetscFunctionBeginUser;
-  ierr = PetscPrintf(PETSC_COMM_WORLD,"iter = %D,SNES Function norm %g\n",its,(double)fnorm);CHKERRQ(ierr);
-  ierr = SNESGetSolution(snes,&x);CHKERRQ(ierr);
-  ierr = VecView(x,monP->viewer);CHKERRQ(ierr);
+  PetscCall(PetscPrintf(PETSC_COMM_WORLD, "iter = %" PetscInt_FMT ",SNES Function norm %g\n", its, (double)fnorm));
+  PetscCall(SNESGetSolution(snes, &x));
+  PetscCall(VecView(x, monP->viewer));
   PetscFunctionReturn(0);
 }
 
@@ -547,7 +542,7 @@ PetscErrorCode Monitor(SNES snes,PetscInt its,PetscReal fnorm,void *ctx)
    y         - proposed step (search direction and length) (possibly changed)
    changed_y - tells if the step has changed or not
  */
-PetscErrorCode PreCheck(SNESLineSearch linesearch,Vec xcurrent,Vec y, PetscBool *changed_y, void * ctx)
+PetscErrorCode PreCheck(SNESLineSearch linesearch, Vec xcurrent, Vec y, PetscBool *changed_y, void *ctx)
 {
   PetscFunctionBeginUser;
   *changed_y = PETSC_FALSE;
@@ -572,35 +567,34 @@ PetscErrorCode PreCheck(SNESLineSearch linesearch,Vec xcurrent,Vec y, PetscBool
    x    - current iterate (possibly modified)
 
  */
-PetscErrorCode PostCheck(SNESLineSearch linesearch,Vec xcurrent,Vec y,Vec x,PetscBool  *changed_y,PetscBool  *changed_x, void * ctx)
+PetscErrorCode PostCheck(SNESLineSearch linesearch, Vec xcurrent, Vec y, Vec x, PetscBool *changed_y, PetscBool *changed_x, void *ctx)
 {
-  PetscErrorCode ierr;
-  PetscInt       i,iter,xs,xm;
+  PetscInt        i, iter, xs, xm;
   StepCheckCtx   *check;
   ApplicationCtx *user;
-  PetscScalar    *xa,*xa_last,tmp;
-  PetscReal      rdiff;
-  DM             da;
-  SNES           snes;
+  PetscScalar    *xa, *xa_last, tmp;
+  PetscReal       rdiff;
+  DM              da;
+  SNES            snes;
 
   PetscFunctionBeginUser;
   *changed_x = PETSC_FALSE;
   *changed_y = PETSC_FALSE;
 
-  ierr  = SNESLineSearchGetSNES(linesearch, &snes);CHKERRQ(ierr);
-  check = (StepCheckCtx*)ctx;
+  PetscCall(SNESLineSearchGetSNES(linesearch, &snes));
+  check = (StepCheckCtx *)ctx;
   user  = check->user;
-  ierr  = SNESGetIterationNumber(snes,&iter);CHKERRQ(ierr);
+  PetscCall(SNESGetIterationNumber(snes, &iter));
 
   /* iteration 1 indicates we are working on the second iteration */
   if (iter > 0) {
-    da   = user->da;
-    ierr = PetscPrintf(PETSC_COMM_WORLD,"Checking candidate step at iteration %D with tolerance %g\n",iter,(double)check->tolerance);CHKERRQ(ierr);
+    da = user->da;
+    PetscCall(PetscPrintf(PETSC_COMM_WORLD, "Checking candidate step at iteration %" PetscInt_FMT " with tolerance %g\n", iter, (double)check->tolerance));
 
     /* Access local array data */
-    ierr = DMDAVecGetArray(da,check->last_step,&xa_last);CHKERRQ(ierr);
-    ierr = DMDAVecGetArray(da,x,&xa);CHKERRQ(ierr);
-    ierr = DMDAGetCorners(da,&xs,NULL,NULL,&xm,NULL,NULL);CHKERRQ(ierr);
+    PetscCall(DMDAVecGetArray(da, check->last_step, &xa_last));
+    PetscCall(DMDAVecGetArray(da, x, &xa));
+    PetscCall(DMDAGetCorners(da, &xs, NULL, NULL, &xm, NULL, NULL));
 
     /*
        If we fail the user-defined check for validity of the candidate iterate,
@@ -608,20 +602,20 @@ PetscErrorCode PostCheck(SNESLineSearch linesearch,Vec xcurrent,Vec y,Vec x,Pets
        below is intended simply to demonstrate how to manipulate this data, not
        as a meaningful or appropriate choice.)
     */
-    for (i=xs; i<xs+xm; i++) {
-      if (!PetscAbsScalar(xa[i])) rdiff = 2*check->tolerance;
-      else rdiff = PetscAbsScalar((xa[i] - xa_last[i])/xa[i]);
+    for (i = xs; i < xs + xm; i++) {
+      if (!PetscAbsScalar(xa[i])) rdiff = 2 * check->tolerance;
+      else rdiff = PetscAbsScalar((xa[i] - xa_last[i]) / xa[i]);
       if (rdiff > check->tolerance) {
         tmp        = xa[i];
-        xa[i]      = .5*(xa[i] + xa_last[i]);
+        xa[i]      = .5 * (xa[i] + xa_last[i]);
         *changed_x = PETSC_TRUE;
-        ierr       = PetscPrintf(PETSC_COMM_WORLD,"  Altering entry %D: x=%g, x_last=%g, diff=%g, x_new=%g\n",i,(double)PetscAbsScalar(tmp),(double)PetscAbsScalar(xa_last[i]),(double)rdiff,(double)PetscAbsScalar(xa[i]));CHKERRQ(ierr);
+        PetscCall(PetscPrintf(PETSC_COMM_WORLD, "  Altering entry %" PetscInt_FMT ": x=%g, x_last=%g, diff=%g, x_new=%g\n", i, (double)PetscAbsScalar(tmp), (double)PetscAbsScalar(xa_last[i]), (double)rdiff, (double)PetscAbsScalar(xa[i])));
       }
     }
-    ierr = DMDAVecRestoreArray(da,check->last_step,&xa_last);CHKERRQ(ierr);
-    ierr = DMDAVecRestoreArray(da,x,&xa);CHKERRQ(ierr);
+    PetscCall(DMDAVecRestoreArray(da, check->last_step, &xa_last));
+    PetscCall(DMDAVecRestoreArray(da, x, &xa));
   }
-  ierr = VecCopy(x,check->last_step);CHKERRQ(ierr);
+  PetscCall(VecCopy(x, check->last_step));
   PetscFunctionReturn(0);
 }
 
@@ -643,34 +637,33 @@ PetscErrorCode PostCheck(SNESLineSearch linesearch,Vec xcurrent,Vec y,Vec x,Pets
    x    - current iterate (possibly modified)
 
  */
-PetscErrorCode PostSetSubKSP(SNESLineSearch linesearch,Vec xcurrent,Vec y,Vec x,PetscBool  *changed_y,PetscBool  *changed_x, void * ctx)
+PetscErrorCode PostSetSubKSP(SNESLineSearch linesearch, Vec xcurrent, Vec y, Vec x, PetscBool *changed_y, PetscBool *changed_x, void *ctx)
 {
-  PetscErrorCode ierr;
-  SetSubKSPCtx   *check;
-  PetscInt       iter,its,sub_its,maxit;
-  KSP            ksp,sub_ksp,*sub_ksps;
-  PC             pc;
-  PetscReal      ksp_ratio;
-  SNES           snes;
+  SetSubKSPCtx *check;
+  PetscInt      iter, its, sub_its, maxit;
+  KSP           ksp, sub_ksp, *sub_ksps;
+  PC            pc;
+  PetscReal     ksp_ratio;
+  SNES          snes;
 
   PetscFunctionBeginUser;
-  ierr    = SNESLineSearchGetSNES(linesearch, &snes);CHKERRQ(ierr);
-  check   = (SetSubKSPCtx*)ctx;
-  ierr    = SNESGetIterationNumber(snes,&iter);CHKERRQ(ierr);
-  ierr    = SNESGetKSP(snes,&ksp);CHKERRQ(ierr);
-  ierr    = KSPGetPC(ksp,&pc);CHKERRQ(ierr);
-  ierr    = PCBJacobiGetSubKSP(pc,NULL,NULL,&sub_ksps);CHKERRQ(ierr);
+  PetscCall(SNESLineSearchGetSNES(linesearch, &snes));
+  check = (SetSubKSPCtx *)ctx;
+  PetscCall(SNESGetIterationNumber(snes, &iter));
+  PetscCall(SNESGetKSP(snes, &ksp));
+  PetscCall(KSPGetPC(ksp, &pc));
+  PetscCall(PCBJacobiGetSubKSP(pc, NULL, NULL, &sub_ksps));
   sub_ksp = sub_ksps[0];
-  ierr    = KSPGetIterationNumber(ksp,&its);CHKERRQ(ierr);      /* outer KSP iteration number */
-  ierr    = KSPGetIterationNumber(sub_ksp,&sub_its);CHKERRQ(ierr); /* inner KSP iteration number */
+  PetscCall(KSPGetIterationNumber(ksp, &its));         /* outer KSP iteration number */
+  PetscCall(KSPGetIterationNumber(sub_ksp, &sub_its)); /* inner KSP iteration number */
 
   if (iter) {
-    ierr      = PetscPrintf(PETSC_COMM_WORLD,"    ...PostCheck snes iteration %D, ksp_it %D %D, subksp_it %D\n",iter,check->its0,its,sub_its);CHKERRQ(ierr);
-    ksp_ratio = ((PetscReal)(its))/check->its0;
-    maxit     = (PetscInt)(ksp_ratio*sub_its + 0.5);
+    PetscCall(PetscPrintf(PETSC_COMM_WORLD, "    ...PostCheck snes iteration %" PetscInt_FMT ", ksp_it %" PetscInt_FMT " %" PetscInt_FMT ", subksp_it %" PetscInt_FMT "\n", iter, check->its0, its, sub_its));
+    ksp_ratio = ((PetscReal)(its)) / check->its0;
+    maxit     = (PetscInt)(ksp_ratio * sub_its + 0.5);
     if (maxit < 2) maxit = 2;
-    ierr = KSPSetTolerances(sub_ksp,PETSC_DEFAULT,PETSC_DEFAULT,PETSC_DEFAULT,maxit);CHKERRQ(ierr);
-    ierr = PetscPrintf(PETSC_COMM_WORLD,"    ...ksp_ratio %g, new maxit %D\n\n",(double)ksp_ratio,maxit);CHKERRQ(ierr);
+    PetscCall(KSPSetTolerances(sub_ksp, PETSC_DEFAULT, PETSC_DEFAULT, PETSC_DEFAULT, maxit));
+    PetscCall(PetscPrintf(PETSC_COMM_WORLD, "    ...ksp_ratio %g, new maxit %" PetscInt_FMT "\n\n", (double)ksp_ratio, maxit));
   }
   check->its0 = its; /* save current outer KSP iteration number */
   PetscFunctionReturn(0);
@@ -689,14 +682,12 @@ PetscErrorCode PostSetSubKSP(SNESLineSearch linesearch,Vec xcurrent,Vec y,Vec x,
    Output Parameter:
 .  y - preconditioned vector
 */
-PetscErrorCode MatrixFreePreconditioner(PC pc,Vec x,Vec y)
+PetscErrorCode MatrixFreePreconditioner(PC pc, Vec x, Vec y)
 {
-  PetscErrorCode ierr;
-  ierr = VecCopy(x,y);CHKERRQ(ierr);
+  PetscCall(VecCopy(x, y));
   return 0;
 }
 
-
 /*TEST
 
    test:
@@ -763,4 +754,10 @@ PetscErrorCode MatrixFreePreconditioner(PC pc,Vec x,Vec y)
       args: -view_initial
       filter: grep -v "type:"
 
+   test:
+      suffix: 13
+      requires: double !complex !single
+      nsize: 4
+      args: -test_jacobian_domain_error -snes_converged_reason -snes_type newtontrdc -snes_check_jacobian_domain_error 1
+
 TEST*/
